@@ -1,20 +1,20 @@
-/*
-** Copyright 2014, 2021 Centreon
-**
-** Licensed under the Apache License, Version 2.0 (the "License");
-** you may not use this file except in compliance with the License.
-** You may obtain a copy of the License at
-**
-**     http://www.apache.org/licenses/LICENSE-2.0
-**
-** Unless required by applicable law or agreed to in writing, software
-** distributed under the License is distributed on an "AS IS" BASIS,
-** WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-** See the License for the specific language governing permissions and
-** limitations under the License.
-**
-** For more information : contact@centreon.com
-*/
+/**
+ * Copyright 2014, 2021 Centreon
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * For more information : contact@centreon.com
+ */
 
 #include "com/centreon/broker/bam/kpi_service.hh"
 #include <fmt/format.h>
@@ -32,26 +32,27 @@
 #include "com/centreon/broker/neb/acknowledgement.hh"
 #include "com/centreon/broker/neb/downtime.hh"
 #include "com/centreon/broker/neb/service_status.hh"
+#include "common/log_v2/log_v2.hh"
 #include "test-visitor.hh"
 
 using namespace com::centreon::broker;
 
-extern std::shared_ptr<asio::io_context> g_io_context;
 
 class BamBA : public ::testing::Test {
  protected:
   std::unique_ptr<bam::configuration::applier::state> _aply_state;
   std::unique_ptr<bam::configuration::state> _state;
   std::unique_ptr<test_visitor> _visitor;
+  std::shared_ptr<spdlog::logger> _logger;
 
  public:
   void SetUp() override {
     // Initialization.
-    g_io_context->restart();
+    _logger = log_v2::instance().get(log_v2::BAM);
     config::applier::init(0, "test_broker", 0);
 
-    _aply_state = std::make_unique<bam::configuration::applier::state>();
-    _state = std::make_unique<bam::configuration::state>();
+    _aply_state = std::make_unique<bam::configuration::applier::state>(_logger);
+    _state = std::make_unique<bam::configuration::state>(_logger);
     _visitor = std::make_unique<test_visitor>("test-visitor");
   }
 
@@ -68,12 +69,12 @@ class BamBA : public ::testing::Test {
 TEST_F(BamBA, KpiServiceRecompute) {
   // Build BAM objects.
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_impact>(1, 1, 1, true)};
+      std::make_shared<bam::ba_impact>(1, 1, 1, true, _logger)};
   test_ba->set_level_critical(0);
   test_ba->set_level_warning(25);
 
   std::shared_ptr<bam::kpi_service> kpi{
-      std::make_shared<bam::kpi_service>(1, 1, 1, 1, "host_1/serv_1")};
+      std::make_shared<bam::kpi_service>(1, 1, 1, 1, "host_1/serv_1", _logger)};
 
   kpi->set_impact_critical(100.0);
   kpi->set_state_hard(bam::state_ok);
@@ -122,14 +123,14 @@ TEST_F(BamBA, KpiServiceRecompute) {
 TEST_F(BamBA, KpiServiceImpactState) {
   // Build BAM objects.
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_impact>(1, 1, 2, true)};
+      std::make_shared<bam::ba_impact>(1, 1, 2, true, _logger)};
 
   std::vector<std::shared_ptr<bam::kpi_service>> kpis;
   std::vector<short> results{0, 0, 1, 1, 1, 2};
 
   for (int i = 0; i < 3; i++) {
     auto s = std::make_shared<bam::kpi_service>(
-        i + 1, 1, i + 1, 1, fmt::format("host_{}/serv_1", i + 1));
+        i + 1, 1, i + 1, 1, fmt::format("host_{}/serv_1", i + 1), _logger);
     s->set_impact_warning(10);
     s->set_impact_critical(20);
     s->set_state_hard(bam::state_ok);
@@ -243,14 +244,14 @@ TEST_F(BamBA, KpiServiceImpactState) {
 TEST_F(BamBA, KpiServiceBestState) {
   // Build BAM objects.
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_best>(1, 1, 3, true)};
+      std::make_shared<bam::ba_best>(1, 1, 3, true, _logger)};
 
   std::vector<std::shared_ptr<bam::kpi_service>> kpis;
   std::vector<short> results{0, 0, 1, 1, 1, 2};
 
   for (size_t i = 0; i < 3; i++) {
-    auto s = std::make_shared<bam::kpi_service>(i + 1, 1, i + 1, 1,
-                                                fmt::format("service {}", i));
+    auto s = std::make_shared<bam::kpi_service>(
+        i + 1, 1, i + 1, 1, fmt::format("service {}", i), _logger);
     s->set_state_hard(bam::state_ok);
     s->set_state_soft(s->get_state_hard());
     test_ba->add_impact(s);
@@ -301,14 +302,14 @@ TEST_F(BamBA, KpiServiceBestState) {
 TEST_F(BamBA, KpiServiceWorstState) {
   // Build BAM objects.
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_worst>(1, 1, 4, true)};
+      std::make_shared<bam::ba_worst>(1, 1, 4, true, _logger)};
 
   std::vector<std::shared_ptr<bam::kpi_service>> kpis;
   std::vector<short> results{1, 1, 1, 2, 2, 2};
 
   for (int i = 0; i < 3; i++) {
-    auto s = std::make_shared<bam::kpi_service>(i + 1, 1, i + 1, 1,
-                                                fmt::format("service {}", i));
+    auto s = std::make_shared<bam::kpi_service>(
+        i + 1, 1, i + 1, 1, fmt::format("service {}", i), _logger);
     s->set_impact_warning(10);
     s->set_impact_critical(20);
     s->set_state_hard(bam::state_ok);
@@ -398,7 +399,7 @@ TEST_F(BamBA, KpiServiceWorstState) {
 TEST_F(BamBA, KpiServiceRatioNum) {
   // Build BAM objects.
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_ratio_number>(1, 1, 4, true)};
+      std::make_shared<bam::ba_ratio_number>(1, 1, 4, true, _logger)};
   test_ba->set_level_critical(4);
   test_ba->set_level_warning(2);
 
@@ -406,8 +407,8 @@ TEST_F(BamBA, KpiServiceRatioNum) {
   std::stack<short> results{{2, 1, 1, 0}};
 
   for (int i = 0; i < 4; i++) {
-    auto s = std::make_shared<bam::kpi_service>(i + 1, 1, i + 1, 1,
-                                                fmt::format("service {}", i));
+    auto s = std::make_shared<bam::kpi_service>(
+        i + 1, 1, i + 1, 1, fmt::format("service {}", i), _logger);
     s->set_state_hard(bam::state_ok);
     s->set_state_soft(s->get_state_hard());
     test_ba->add_impact(s);
@@ -455,7 +456,7 @@ TEST_F(BamBA, KpiServiceRatioNum) {
 TEST_F(BamBA, KpiServiceRatioPercent) {
   // Build BAM objects.
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_ratio_percent>(1, 1, 4, true)};
+      std::make_shared<bam::ba_ratio_percent>(1, 1, 4, true, _logger)};
   test_ba->set_level_critical(100);
   test_ba->set_level_warning(75);
 
@@ -463,8 +464,8 @@ TEST_F(BamBA, KpiServiceRatioPercent) {
   std::stack<short> results({2, 1, 0, 0});
 
   for (int i = 0; i < 4; i++) {
-    auto s = std::make_shared<bam::kpi_service>(i + 1, 1, i + 1, 1,
-                                                fmt::format("service {}", i));
+    auto s = std::make_shared<bam::kpi_service>(
+        i + 1, 1, i + 1, 1, fmt::format("service {}", i), _logger);
     s->set_state_hard(bam::state_ok);
     s->set_state_soft(s->get_state_hard());
     test_ba->add_impact(s);
@@ -496,7 +497,7 @@ TEST_F(BamBA, KpiServiceRatioPercent) {
 
 TEST_F(BamBA, KpiServiceDtInheritAllCritical) {
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_ratio_percent>(1, 1, 4, true)};
+      std::make_shared<bam::ba_ratio_percent>(1, 1, 4, true, _logger)};
   test_ba->set_level_critical(100);
   test_ba->set_level_warning(75);
   test_ba->set_downtime_behaviour(bam::configuration::ba::dt_inherit);
@@ -505,8 +506,8 @@ TEST_F(BamBA, KpiServiceDtInheritAllCritical) {
   std::stack<bool> results({true, false, false, false});
 
   for (int i = 0; i < 4; i++) {
-    auto s = std::make_shared<bam::kpi_service>(i + 1, 1, i + 1, 1,
-                                                fmt::format("service {}", i));
+    auto s = std::make_shared<bam::kpi_service>(
+        i + 1, 1, i + 1, 1, fmt::format("service {}", i), _logger);
     s->set_state_hard(bam::state_critical);
     s->set_state_soft(s->get_state_hard());
     test_ba->add_impact(s);
@@ -544,7 +545,7 @@ TEST_F(BamBA, KpiServiceDtInheritAllCritical) {
 
 TEST_F(BamBA, KpiServiceDtInheritAllCriticalPb) {
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_ratio_percent>(1, 1, 4, true)};
+      std::make_shared<bam::ba_ratio_percent>(1, 1, 4, true, _logger)};
   test_ba->set_level_critical(100);
   test_ba->set_level_warning(75);
   test_ba->set_downtime_behaviour(bam::configuration::ba::dt_inherit);
@@ -553,8 +554,8 @@ TEST_F(BamBA, KpiServiceDtInheritAllCriticalPb) {
   std::stack<bool> results({true, false, false, false});
 
   for (int i = 0; i < 4; i++) {
-    auto s = std::make_shared<bam::kpi_service>(i + 1, 1, i + 1, 1,
-                                                fmt::format("service {}", i));
+    auto s = std::make_shared<bam::kpi_service>(
+        i + 1, 1, i + 1, 1, fmt::format("service {}", i), _logger);
     s->set_state_hard(bam::state_critical);
     s->set_state_soft(s->get_state_hard());
     test_ba->add_impact(s);
@@ -594,7 +595,7 @@ TEST_F(BamBA, KpiServiceDtInheritAllCriticalPb) {
 
 TEST_F(BamBA, KpiServiceDtInheritOneOK) {
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_ratio_percent>(1, 1, 4, true)};
+      std::make_shared<bam::ba_ratio_percent>(1, 1, 4, true, _logger)};
   test_ba->set_level_critical(100);
   test_ba->set_level_warning(90);
   test_ba->set_downtime_behaviour(bam::configuration::ba::dt_inherit);
@@ -603,8 +604,8 @@ TEST_F(BamBA, KpiServiceDtInheritOneOK) {
   std::stack<bool> results({false, false, false, false});
 
   for (int i = 0; i < 4; i++) {
-    auto s = std::make_shared<bam::kpi_service>(i + 1, 1, i + 1, 1,
-                                                fmt::format("service {}", i));
+    auto s = std::make_shared<bam::kpi_service>(
+        i + 1, 1, i + 1, 1, fmt::format("service {}", i), _logger);
     if (i == 0)
       s->set_state_hard(bam::state_ok);
     else
@@ -650,7 +651,7 @@ TEST_F(BamBA, KpiServiceDtInheritOneOK) {
 
 TEST_F(BamBA, KpiServiceDtInheritOneOKPb) {
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_ratio_percent>(1, 1, 4, true)};
+      std::make_shared<bam::ba_ratio_percent>(1, 1, 4, true, _logger)};
   test_ba->set_level_critical(100);
   test_ba->set_level_warning(90);
   test_ba->set_downtime_behaviour(bam::configuration::ba::dt_inherit);
@@ -659,8 +660,8 @@ TEST_F(BamBA, KpiServiceDtInheritOneOKPb) {
   std::stack<bool> results({false, false, false, false});
 
   for (int i = 0; i < 4; i++) {
-    auto s = std::make_shared<bam::kpi_service>(i + 1, 1, i + 1, 1,
-                                                fmt::format("service {}", i));
+    auto s = std::make_shared<bam::kpi_service>(
+        i + 1, 1, i + 1, 1, fmt::format("service {}", i), _logger);
     if (i == 0)
       s->set_state_hard(bam::state_ok);
     else
@@ -708,7 +709,7 @@ TEST_F(BamBA, KpiServiceDtInheritOneOKPb) {
 
 TEST_F(BamBA, KpiServiceIgnoreDt) {
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_ratio_percent>(1, 1, 4, true)};
+      std::make_shared<bam::ba_ratio_percent>(1, 1, 4, true, _logger)};
   test_ba->set_level_critical(100);
   test_ba->set_level_warning(75);
   test_ba->set_downtime_behaviour(bam::configuration::ba::dt_ignore);
@@ -717,8 +718,8 @@ TEST_F(BamBA, KpiServiceIgnoreDt) {
   std::stack<bool> results({false, false, false, false});
 
   for (int i = 0; i < 4; i++) {
-    auto s = std::make_shared<bam::kpi_service>(i + 1, 1, i + 1, 1,
-                                                fmt::format("service {}", i));
+    auto s = std::make_shared<bam::kpi_service>(
+        i + 1, 1, i + 1, 1, fmt::format("service {}", i), _logger);
     s->set_state_hard(bam::state_critical);
     s->set_state_soft(s->get_state_hard());
     test_ba->add_impact(s);
@@ -756,7 +757,7 @@ TEST_F(BamBA, KpiServiceIgnoreDt) {
 
 TEST_F(BamBA, KpiServiceIgnoreDtPb) {
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_ratio_percent>(1, 1, 4, true)};
+      std::make_shared<bam::ba_ratio_percent>(1, 1, 4, true, _logger)};
   test_ba->set_level_critical(100);
   test_ba->set_level_warning(75);
   test_ba->set_downtime_behaviour(bam::configuration::ba::dt_ignore);
@@ -765,8 +766,8 @@ TEST_F(BamBA, KpiServiceIgnoreDtPb) {
   std::stack<bool> results({false, false, false, false});
 
   for (int i = 0; i < 4; i++) {
-    auto s = std::make_shared<bam::kpi_service>(i + 1, 1, i + 1, 1,
-                                                fmt::format("service {}", i));
+    auto s = std::make_shared<bam::kpi_service>(
+        i + 1, 1, i + 1, 1, fmt::format("service {}", i), _logger);
     s->set_state_hard(bam::state_critical);
     s->set_state_soft(s->get_state_hard());
     test_ba->add_impact(s);
@@ -807,7 +808,7 @@ TEST_F(BamBA, KpiServiceIgnoreDtPb) {
 
 TEST_F(BamBA, KpiServiceDtIgnoreKpi) {
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_ratio_percent>(1, 1, 4, true)};
+      std::make_shared<bam::ba_ratio_percent>(1, 1, 4, true, _logger)};
   test_ba->set_level_critical(100);
   test_ba->set_level_warning(75);
   test_ba->set_downtime_behaviour(bam::configuration::ba::dt_ignore_kpi);
@@ -816,8 +817,8 @@ TEST_F(BamBA, KpiServiceDtIgnoreKpi) {
   std::stack<bool> results({false, false, false, false});
 
   for (int i = 0; i < 4; i++) {
-    auto s = std::make_shared<bam::kpi_service>(i + 1, 1, i + 1, 1,
-                                                fmt::format("service {}", i));
+    auto s = std::make_shared<bam::kpi_service>(
+        i + 1, 1, i + 1, 1, fmt::format("service {}", i), _logger);
     s->set_state_hard(bam::state_critical);
     s->set_state_soft(s->get_state_hard());
     test_ba->add_impact(s);
@@ -855,7 +856,7 @@ TEST_F(BamBA, KpiServiceDtIgnoreKpi) {
 
 TEST_F(BamBA, KpiServiceDtIgnoreKpiPb) {
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_ratio_percent>(1, 1, 4, true)};
+      std::make_shared<bam::ba_ratio_percent>(1, 1, 4, true, _logger)};
   test_ba->set_level_critical(100);
   test_ba->set_level_warning(75);
   test_ba->set_downtime_behaviour(bam::configuration::ba::dt_ignore_kpi);
@@ -864,8 +865,8 @@ TEST_F(BamBA, KpiServiceDtIgnoreKpiPb) {
   std::stack<bool> results({false, false, false, false});
 
   for (int i = 0; i < 4; i++) {
-    auto s = std::make_shared<bam::kpi_service>(i + 1, 1, i + 1, 1,
-                                                fmt::format("service {}", i));
+    auto s = std::make_shared<bam::kpi_service>(
+        i + 1, 1, i + 1, 1, fmt::format("service {}", i), _logger);
     s->set_state_hard(bam::state_critical);
     s->set_state_soft(s->get_state_hard());
     test_ba->add_impact(s);
@@ -906,7 +907,7 @@ TEST_F(BamBA, KpiServiceDtIgnoreKpiPb) {
 
 TEST_F(BamBA, KpiServiceDtIgnoreKpiImpact) {
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_impact>(1, 1, 4, true)};
+      std::make_shared<bam::ba_impact>(1, 1, 4, true, _logger)};
   test_ba->set_level_critical(50);
   test_ba->set_level_warning(75);
   test_ba->set_downtime_behaviour(bam::configuration::ba::dt_ignore_kpi);
@@ -920,8 +921,8 @@ TEST_F(BamBA, KpiServiceDtIgnoreKpiImpact) {
   results.push(2);
 
   for (int i = 0; i < 4; i++) {
-    auto s = std::make_shared<bam::kpi_service>(i + 1, 1, i + 1, 1,
-                                                fmt::format("service {}", i));
+    auto s = std::make_shared<bam::kpi_service>(
+        i + 1, 1, i + 1, 1, fmt::format("service {}", i), _logger);
     if (i == 3)
       s->set_state_hard(bam::state_ok);
     else
@@ -966,7 +967,7 @@ TEST_F(BamBA, KpiServiceDtIgnoreKpiImpact) {
 
 TEST_F(BamBA, KpiServiceDtIgnoreKpiImpactPb) {
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_impact>(1, 1, 4, true)};
+      std::make_shared<bam::ba_impact>(1, 1, 4, true, _logger)};
   test_ba->set_level_critical(50);
   test_ba->set_level_warning(75);
   test_ba->set_downtime_behaviour(bam::configuration::ba::dt_ignore_kpi);
@@ -975,8 +976,8 @@ TEST_F(BamBA, KpiServiceDtIgnoreKpiImpactPb) {
   std::stack<short> results({0, 0, 1, 2});
 
   for (int i = 0; i < 4; i++) {
-    auto s = std::make_shared<bam::kpi_service>(i + 1, 1, i + 1, 1,
-                                                fmt::format("service {}", i));
+    auto s = std::make_shared<bam::kpi_service>(
+        i + 1, 1, i + 1, 1, fmt::format("service {}", i), _logger);
     if (i == 3)
       s->set_state_hard(bam::state_ok);
     else
@@ -1024,15 +1025,15 @@ TEST_F(BamBA, KpiServiceDtIgnoreKpiImpactPb) {
 
 TEST_F(BamBA, KpiServiceDtIgnoreKpiBest) {
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_best>(1, 1, 4, true)};
+      std::make_shared<bam::ba_best>(1, 1, 4, true, _logger)};
   test_ba->set_downtime_behaviour(bam::configuration::ba::dt_ignore_kpi);
 
   std::vector<std::shared_ptr<bam::kpi_service>> kpis;
   std::stack<short> results({0, 2, 1, 0});
 
   for (int i = 0; i < 4; i++) {
-    auto s = std::make_shared<bam::kpi_service>(i + 1, 1, i + 1, 1,
-                                                fmt::format("service {}", i));
+    auto s = std::make_shared<bam::kpi_service>(
+        i + 1, 1, i + 1, 1, fmt::format("service {}", i), _logger);
     switch (i) {
       case 0:
       case 1:
@@ -1081,15 +1082,15 @@ TEST_F(BamBA, KpiServiceDtIgnoreKpiBest) {
 
 TEST_F(BamBA, KpiServiceDtIgnoreKpiBestPb) {
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_best>(1, 1, 4, true)};
+      std::make_shared<bam::ba_best>(1, 1, 4, true, _logger)};
   test_ba->set_downtime_behaviour(bam::configuration::ba::dt_ignore_kpi);
 
   std::vector<std::shared_ptr<bam::kpi_service>> kpis;
   std::stack<short> results({0, 2, 1, 0});
 
   for (int i = 0; i < 4; i++) {
-    auto s = std::make_shared<bam::kpi_service>(i + 1, 1, i + 1, 1,
-                                                fmt::format("service {}", i));
+    auto s = std::make_shared<bam::kpi_service>(
+        i + 1, 1, i + 1, 1, fmt::format("service {}", i), _logger);
     switch (i) {
       case 0:
       case 1:
@@ -1142,15 +1143,15 @@ TEST_F(BamBA, KpiServiceDtIgnoreKpiBestPb) {
 
 TEST_F(BamBA, KpiServiceDtIgnoreKpiWorst) {
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_worst>(1, 1, 4, true)};
+      std::make_shared<bam::ba_worst>(1, 1, 4, true, _logger)};
   test_ba->set_downtime_behaviour(bam::configuration::ba::dt_ignore_kpi);
 
   std::vector<std::shared_ptr<bam::kpi_service>> kpis;
   std::stack<short> results({0, 0, 1, 2});
 
   for (int i = 0; i < 4; i++) {
-    auto s = std::make_shared<bam::kpi_service>(i + 1, 1, i + 1, 1,
-                                                fmt::format("service {}", i));
+    auto s = std::make_shared<bam::kpi_service>(
+        i + 1, 1, i + 1, 1, fmt::format("service {}", i), _logger);
     switch (i) {
       case 0:
       case 1:
@@ -1199,15 +1200,15 @@ TEST_F(BamBA, KpiServiceDtIgnoreKpiWorst) {
 
 TEST_F(BamBA, KpiServiceDtIgnoreKpiWorstPb) {
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_worst>(1, 1, 4, true)};
+      std::make_shared<bam::ba_worst>(1, 1, 4, true, _logger)};
   test_ba->set_downtime_behaviour(bam::configuration::ba::dt_ignore_kpi);
 
   std::vector<std::shared_ptr<bam::kpi_service>> kpis;
   std::stack<short> results({0, 0, 1, 2});
 
   for (int i = 0; i < 4; i++) {
-    auto s = std::make_shared<bam::kpi_service>(i + 1, 1, i + 1, 1,
-                                                fmt::format("service {}", i));
+    auto s = std::make_shared<bam::kpi_service>(
+        i + 1, 1, i + 1, 1, fmt::format("service {}", i), _logger);
     switch (i) {
       case 0:
       case 1:
@@ -1259,7 +1260,7 @@ TEST_F(BamBA, KpiServiceDtIgnoreKpiWorstPb) {
 
 TEST_F(BamBA, KpiServiceDtIgnoreKpiRatio) {
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_ratio_number>(1, 1, 4, true)};
+      std::make_shared<bam::ba_ratio_number>(1, 1, 4, true, _logger)};
   test_ba->set_downtime_behaviour(bam::configuration::ba::dt_ignore_kpi);
   test_ba->set_level_warning(1);
   test_ba->set_level_critical(2);
@@ -1268,8 +1269,8 @@ TEST_F(BamBA, KpiServiceDtIgnoreKpiRatio) {
   std::stack<short> results({0, 1, 2, 2});
 
   for (int i = 0; i < 4; i++) {
-    auto s = std::make_shared<bam::kpi_service>(i + 1, 1, i + 1, 1,
-                                                fmt::format("service {}", i));
+    auto s = std::make_shared<bam::kpi_service>(
+        i + 1, 1, i + 1, 1, fmt::format("service {}", i), _logger);
     s->set_state_hard(bam::state_critical);
     s->set_state_soft(s->get_state_hard());
     test_ba->add_impact(s);
@@ -1307,7 +1308,7 @@ TEST_F(BamBA, KpiServiceDtIgnoreKpiRatio) {
 
 TEST_F(BamBA, KpiServiceDtIgnoreKpiRatioPb) {
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_ratio_number>(1, 1, 4, true)};
+      std::make_shared<bam::ba_ratio_number>(1, 1, 4, true, _logger)};
   test_ba->set_downtime_behaviour(bam::configuration::ba::dt_ignore_kpi);
   test_ba->set_level_warning(1);
   test_ba->set_level_critical(2);
@@ -1316,8 +1317,8 @@ TEST_F(BamBA, KpiServiceDtIgnoreKpiRatioPb) {
   std::stack<short> results({0, 1, 2, 2});
 
   for (int i = 0; i < 4; i++) {
-    auto s = std::make_shared<bam::kpi_service>(i + 1, 1, i + 1, 1,
-                                                fmt::format("service {}", i));
+    auto s = std::make_shared<bam::kpi_service>(
+        i + 1, 1, i + 1, 1, fmt::format("service {}", i), _logger);
     s->set_state_hard(bam::state_critical);
     s->set_state_soft(s->get_state_hard());
     test_ba->add_impact(s);
@@ -1359,7 +1360,7 @@ TEST_F(BamBA, KpiServiceDtIgnoreKpiRatioPb) {
 
 TEST_F(BamBA, KpiServiceDt) {
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_ratio_percent>(1, 1, 4, true)};
+      std::make_shared<bam::ba_ratio_percent>(1, 1, 4, true, _logger)};
   test_ba->set_level_critical(100);
   test_ba->set_level_warning(75);
   test_ba->set_downtime_behaviour(bam::configuration::ba::dt_inherit);
@@ -1368,8 +1369,8 @@ TEST_F(BamBA, KpiServiceDt) {
   std::vector<bool> results{false, false, false, true};
 
   for (int i = 0; i < 4; i++) {
-    auto s = std::make_shared<bam::kpi_service>(i + 1, 1, i + 1, 1,
-                                                fmt::format("service {}", i));
+    auto s = std::make_shared<bam::kpi_service>(
+        i + 1, 1, i + 1, 1, fmt::format("service {}", i), _logger);
     s->set_state_hard(bam::state_critical);
     s->set_state_soft(s->get_state_hard());
     test_ba->add_impact(s);
@@ -1520,7 +1521,7 @@ TEST_F(BamBA, KpiServiceDt) {
 
 TEST_F(BamBA, KpiServiceDtPb) {
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_ratio_percent>(1, 1, 4, true)};
+      std::make_shared<bam::ba_ratio_percent>(1, 1, 4, true, _logger)};
   test_ba->set_level_critical(100);
   test_ba->set_level_warning(75);
   test_ba->set_downtime_behaviour(bam::configuration::ba::dt_inherit);
@@ -1529,8 +1530,8 @@ TEST_F(BamBA, KpiServiceDtPb) {
   std::vector<bool> results{false, false, false, true};
 
   for (int i = 0; i < 4; i++) {
-    auto s = std::make_shared<bam::kpi_service>(i + 1, 1, i + 1, 1,
-                                                fmt::format("service {}", i));
+    auto s = std::make_shared<bam::kpi_service>(
+        i + 1, 1, i + 1, 1, fmt::format("service {}", i), _logger);
     s->set_state_hard(bam::state_critical);
     s->set_state_soft(s->get_state_hard());
     test_ba->add_impact(s);
@@ -1684,7 +1685,7 @@ TEST_F(BamBA, KpiServiceDtPb) {
 
 TEST_F(BamBA, KpiServiceDtInherited_set) {
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_ratio_percent>(1, 1, 4, true)};
+      std::make_shared<bam::ba_ratio_percent>(1, 1, 4, true, _logger)};
   test_ba->set_level_critical(100);
   test_ba->set_level_warning(75);
   test_ba->set_downtime_behaviour(bam::configuration::ba::dt_inherit);
@@ -1693,8 +1694,8 @@ TEST_F(BamBA, KpiServiceDtInherited_set) {
   std::vector<bool> results{false, false, false, true};
 
   for (int i = 0; i < 4; i++) {
-    auto s = std::make_shared<bam::kpi_service>(i + 1, 1, i + 1, 1,
-                                                fmt::format("service {}", i));
+    auto s = std::make_shared<bam::kpi_service>(
+        i + 1, 1, i + 1, 1, fmt::format("service {}", i), _logger);
     s->set_state_hard(bam::state_critical);
     s->set_state_soft(s->get_state_hard());
     test_ba->add_impact(s);
@@ -1743,7 +1744,7 @@ TEST_F(BamBA, KpiServiceDtInherited_set) {
 
 TEST_F(BamBA, KpiServiceDtInherited_setPb) {
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_ratio_percent>(1, 1, 4, true)};
+      std::make_shared<bam::ba_ratio_percent>(1, 1, 4, true, _logger)};
   test_ba->set_level_critical(100);
   test_ba->set_level_warning(75);
   test_ba->set_downtime_behaviour(bam::configuration::ba::dt_inherit);
@@ -1752,8 +1753,8 @@ TEST_F(BamBA, KpiServiceDtInherited_setPb) {
   std::vector<bool> results{false, false, false, true};
 
   for (int i = 0; i < 4; i++) {
-    auto s = std::make_shared<bam::kpi_service>(i + 1, 1, i + 1, 1,
-                                                fmt::format("service {}", i));
+    auto s = std::make_shared<bam::kpi_service>(
+        i + 1, 1, i + 1, 1, fmt::format("service {}", i), _logger);
     s->set_state_hard(bam::state_critical);
     s->set_state_soft(s->get_state_hard());
     test_ba->add_impact(s);
@@ -1805,7 +1806,7 @@ TEST_F(BamBA, KpiServiceDtInherited_setPb) {
 
 TEST_F(BamBA, KpiServiceDtInherited_unset) {
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_ratio_percent>(1, 2, 4, true)};
+      std::make_shared<bam::ba_ratio_percent>(1, 2, 4, true, _logger)};
   test_ba->set_level_critical(100);
   test_ba->set_level_warning(75);
   test_ba->set_downtime_behaviour(bam::configuration::ba::dt_inherit);
@@ -1813,8 +1814,8 @@ TEST_F(BamBA, KpiServiceDtInherited_unset) {
   std::vector<std::shared_ptr<bam::kpi_service>> kpis;
 
   for (int i = 0; i < 4; i++) {
-    auto s = std::make_shared<bam::kpi_service>(i + 1, 1, i + 1, 1,
-                                                fmt::format("service {}", i));
+    auto s = std::make_shared<bam::kpi_service>(
+        i + 1, 1, i + 1, 1, fmt::format("service {}", i), _logger);
     s->set_state_hard(bam::state_critical);
     s->set_state_soft(s->get_state_hard());
     test_ba->add_impact(s);
@@ -1851,7 +1852,7 @@ TEST_F(BamBA, KpiServiceDtInherited_unset) {
 
 TEST_F(BamBA, KpiServiceDtInherited_unsetPb) {
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_ratio_percent>(1, 2, 4, true)};
+      std::make_shared<bam::ba_ratio_percent>(1, 2, 4, true, _logger)};
   test_ba->set_level_critical(100);
   test_ba->set_level_warning(75);
   test_ba->set_downtime_behaviour(bam::configuration::ba::dt_inherit);
@@ -1859,8 +1860,8 @@ TEST_F(BamBA, KpiServiceDtInherited_unsetPb) {
   std::vector<std::shared_ptr<bam::kpi_service>> kpis;
 
   for (int i = 0; i < 4; i++) {
-    auto s = std::make_shared<bam::kpi_service>(i + 1, 1, i + 1, 1,
-                                                fmt::format("service {}", i));
+    auto s = std::make_shared<bam::kpi_service>(
+        i + 1, 1, i + 1, 1, fmt::format("service {}", i), _logger);
     s->set_state_hard(bam::state_critical);
     s->set_state_soft(s->get_state_hard());
     test_ba->add_impact(s);
@@ -1898,7 +1899,7 @@ TEST_F(BamBA, KpiServiceDtInherited_unsetPb) {
 
 TEST_F(BamBA, KpiServiceAcknowledgement) {
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_ratio_percent>(1, 2, 4, true)};
+      std::make_shared<bam::ba_ratio_percent>(1, 2, 4, true, _logger)};
   test_ba->set_level_critical(100);
   test_ba->set_level_warning(75);
   test_ba->set_downtime_behaviour(bam::configuration::ba::dt_inherit);
@@ -1906,8 +1907,8 @@ TEST_F(BamBA, KpiServiceAcknowledgement) {
   std::vector<std::shared_ptr<bam::kpi_service>> kpis;
 
   for (int i = 0; i < 4; i++) {
-    auto s = std::make_shared<bam::kpi_service>(i + 1, 1, i + 1, 1,
-                                                fmt::format("service {}", i));
+    auto s = std::make_shared<bam::kpi_service>(
+        i + 1, 1, i + 1, 1, fmt::format("service {}", i), _logger);
     s->set_state_hard(bam::state_critical);
     s->set_state_soft(s->get_state_hard());
     test_ba->add_impact(s);
@@ -1946,7 +1947,7 @@ TEST_F(BamBA, KpiServiceAcknowledgement) {
 
 TEST_F(BamBA, KpiServiceAcknowledgementPb) {
   std::shared_ptr<bam::ba> test_ba{
-      std::make_shared<bam::ba_ratio_percent>(1, 2, 4, true)};
+      std::make_shared<bam::ba_ratio_percent>(1, 2, 4, true, _logger)};
   test_ba->set_level_critical(100);
   test_ba->set_level_warning(75);
   test_ba->set_downtime_behaviour(bam::configuration::ba::dt_inherit);
@@ -1954,8 +1955,8 @@ TEST_F(BamBA, KpiServiceAcknowledgementPb) {
   std::vector<std::shared_ptr<bam::kpi_service>> kpis;
 
   for (int i = 0; i < 4; i++) {
-    auto s = std::make_shared<bam::kpi_service>(i + 1, 1, i + 1, 1,
-                                                fmt::format("service {}", i));
+    auto s = std::make_shared<bam::kpi_service>(
+        i + 1, 1, i + 1, 1, fmt::format("service {}", i), _logger);
     s->set_state_hard(bam::state_critical);
     s->set_state_soft(s->get_state_hard());
     test_ba->add_impact(s);
