@@ -28,25 +28,26 @@
 #include "com/centreon/broker/bam/service_book.hh"
 #include "com/centreon/broker/config/applier/init.hh"
 #include "com/centreon/broker/config/applier/modules.hh"
-#include "com/centreon/broker/log_v2.hh"
 #include "com/centreon/broker/neb/service_status.hh"
+#include "common/log_v2/log_v2.hh"
 #include "test-visitor.hh"
 
 using namespace com::centreon::broker;
+using log_v2 = com::centreon::common::log_v2::log_v2;
 
-extern std::shared_ptr<asio::io_context> g_io_context;
 
 class BamExpBuilder : public ::testing::Test {
  protected:
   std::unique_ptr<test_visitor> _visitor;
+  std::shared_ptr<spdlog::logger> _logger;
 
  public:
   void SetUp() override {
-    g_io_context->restart();
+    _logger = log_v2::instance().get(log_v2::BAM);
     try {
       config::applier::init(0, "test_broker", 0);
-      log_v2::bam()->set_level(spdlog::level::debug);
-      log_v2::bam()->flush_on(spdlog::level::debug);
+      _logger->set_level(spdlog::level::debug);
+      _logger->flush_on(spdlog::level::debug);
     } catch (std::exception const& e) {
       (void)e;
     }
@@ -61,8 +62,8 @@ class BamExpBuilder : public ::testing::Test {
 
 TEST_F(BamExpBuilder, Valid1) {
   bam::exp_parser p("OK IS OK");
-  bam::hst_svc_mapping mapping;
-  bam::exp_builder builder(p.get_postfix(), mapping);
+  bam::hst_svc_mapping mapping(_logger);
+  bam::exp_builder builder(p.get_postfix(), mapping, _logger);
   ASSERT_EQ(builder.get_calls().size(), 0u);
   ASSERT_EQ(builder.get_services().size(), 0u);
   bam::bool_value::ptr b(builder.get_tree());
@@ -73,8 +74,8 @@ TEST_F(BamExpBuilder, Valid1) {
 
 TEST_F(BamExpBuilder, Valid2) {
   bam::exp_parser p("OK IS NOT OK");
-  bam::hst_svc_mapping mapping;
-  bam::exp_builder builder(p.get_postfix(), mapping);
+  bam::hst_svc_mapping mapping(_logger);
+  bam::exp_builder builder(p.get_postfix(), mapping, _logger);
   ASSERT_EQ(builder.get_calls().size(), 0u);
   ASSERT_EQ(builder.get_services().size(), 0u);
   bam::bool_value::ptr b(builder.get_tree());
@@ -85,8 +86,8 @@ TEST_F(BamExpBuilder, Valid2) {
 
 TEST_F(BamExpBuilder, Valid3) {
   bam::exp_parser p("OK AND CRITICAL");
-  bam::hst_svc_mapping mapping;
-  bam::exp_builder builder(p.get_postfix(), mapping);
+  bam::hst_svc_mapping mapping(_logger);
+  bam::exp_builder builder(p.get_postfix(), mapping, _logger);
   ASSERT_EQ(builder.get_calls().size(), 0u);
   ASSERT_EQ(builder.get_services().size(), 0u);
   bam::bool_value::ptr b(builder.get_tree());
@@ -97,8 +98,8 @@ TEST_F(BamExpBuilder, Valid3) {
 
 TEST_F(BamExpBuilder, Valid4) {
   bam::exp_parser p("OK OR CRITICAL");
-  bam::hst_svc_mapping mapping;
-  bam::exp_builder builder(p.get_postfix(), mapping);
+  bam::hst_svc_mapping mapping(_logger);
+  bam::exp_builder builder(p.get_postfix(), mapping, _logger);
   ASSERT_EQ(builder.get_calls().size(), 0u);
   ASSERT_EQ(builder.get_services().size(), 0u);
   bam::bool_value::ptr b(builder.get_tree());
@@ -109,8 +110,8 @@ TEST_F(BamExpBuilder, Valid4) {
 
 TEST_F(BamExpBuilder, Valid5) {
   bam::exp_parser p("OK XOR CRITICAL");
-  bam::hst_svc_mapping mapping;
-  bam::exp_builder builder(p.get_postfix(), mapping);
+  bam::hst_svc_mapping mapping(_logger);
+  bam::exp_builder builder(p.get_postfix(), mapping, _logger);
   ASSERT_EQ(builder.get_calls().size(), 0u);
   ASSERT_EQ(builder.get_services().size(), 0u);
   bam::bool_value::ptr b(builder.get_tree());
@@ -121,8 +122,8 @@ TEST_F(BamExpBuilder, Valid5) {
 
 TEST_F(BamExpBuilder, Valid6) {
   bam::exp_parser p("2 + 3 * 2 == 8");
-  bam::hst_svc_mapping mapping;
-  bam::exp_builder builder(p.get_postfix(), mapping);
+  bam::hst_svc_mapping mapping(_logger);
+  bam::exp_builder builder(p.get_postfix(), mapping, _logger);
   ASSERT_EQ(builder.get_calls().size(), 0u);
   ASSERT_EQ(builder.get_services().size(), 0u);
   bam::bool_value::ptr b(builder.get_tree());
@@ -133,8 +134,8 @@ TEST_F(BamExpBuilder, Valid6) {
 
 TEST_F(BamExpBuilder, Valid7) {
   bam::exp_parser p("2 - 3 * (2 - 6 / 3) == 2");
-  bam::hst_svc_mapping mapping;
-  bam::exp_builder builder(p.get_postfix(), mapping);
+  bam::hst_svc_mapping mapping(_logger);
+  bam::exp_builder builder(p.get_postfix(), mapping, _logger);
   ASSERT_EQ(builder.get_calls().size(), 0u);
   ASSERT_EQ(builder.get_services().size(), 0u);
   bam::bool_value::ptr b(builder.get_tree());
@@ -145,8 +146,8 @@ TEST_F(BamExpBuilder, Valid7) {
 
 TEST_F(BamExpBuilder, Valid8) {
   bam::exp_parser p("2 % 3 == 20 % 6");
-  bam::hst_svc_mapping mapping;
-  bam::exp_builder builder(p.get_postfix(), mapping);
+  bam::hst_svc_mapping mapping(_logger);
+  bam::exp_builder builder(p.get_postfix(), mapping, _logger);
   ASSERT_EQ(builder.get_calls().size(), 0u);
   ASSERT_EQ(builder.get_services().size(), 0u);
   bam::bool_value::ptr b(builder.get_tree());
@@ -156,39 +157,39 @@ TEST_F(BamExpBuilder, Valid8) {
 }
 
 TEST_F(BamExpBuilder, UnknownService1) {
-  config::applier::modules modules;
-  modules.load_file("./lib/10-neb.so");
+  config::applier::modules modules(_logger);
+  modules.load_file("./broker/neb/10-neb.so");
   bam::exp_parser p("{host_1 service_1} {IS} {OK}");
-  bam::hst_svc_mapping mapping;
+  bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
-  bam::exp_builder builder(p.get_postfix(), mapping);
+  bam::exp_builder builder(p.get_postfix(), mapping, _logger);
   bam::bool_value::ptr b(builder.get_tree());
   ASSERT_FALSE(b->state_known());
   ASSERT_FALSE(b->boolean_value());
 }
 
 TEST_F(BamExpBuilder, UnknownService2) {
-  config::applier::modules modules;
-  modules.load_file("./lib/10-neb.so");
+  config::applier::modules modules(_logger);
+  modules.load_file("./broker/neb/10-neb.so");
   bam::exp_parser p("{host_1 service_1} {IS} {CRITICAL}");
-  bam::hst_svc_mapping mapping;
+  bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
-  bam::exp_builder builder(p.get_postfix(), mapping);
+  bam::exp_builder builder(p.get_postfix(), mapping, _logger);
   bam::bool_value::ptr b(builder.get_tree());
   ASSERT_FALSE(b->state_known());
   ASSERT_FALSE(b->boolean_value());
 }
 
 TEST_F(BamExpBuilder, OkService2) {
-  config::applier::modules modules;
-  modules.load_file("./lib/10-neb.so");
+  config::applier::modules modules(_logger);
+  modules.load_file("./broker/neb/10-neb.so");
   bam::exp_parser p("{host_1 service_1} {IS} {CRITICAL}");
-  bam::hst_svc_mapping mapping;
+  bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
-  bam::exp_builder builder(p.get_postfix(), mapping);
+  bam::exp_builder builder(p.get_postfix(), mapping, _logger);
   bam::bool_value::ptr b(builder.get_tree());
 
-  bam::service_book book;
+  bam::service_book book(_logger);
   for (auto& svc : builder.get_services())
     book.listen(svc->get_host_id(), svc->get_service_id(), svc.get());
 
@@ -205,15 +206,15 @@ TEST_F(BamExpBuilder, OkService2) {
 }
 
 TEST_F(BamExpBuilder, CritService2) {
-  config::applier::modules modules;
-  modules.load_file("./lib/10-neb.so");
+  config::applier::modules modules(_logger);
+  modules.load_file("./broker/neb/10-neb.so");
   bam::exp_parser p("{host_1 service_1} {IS} {CRITICAL}");
-  bam::hst_svc_mapping mapping;
+  bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
-  bam::exp_builder builder(p.get_postfix(), mapping);
+  bam::exp_builder builder(p.get_postfix(), mapping, _logger);
   bam::bool_value::ptr b(builder.get_tree());
 
-  bam::service_book book;
+  bam::service_book book(_logger);
   for (auto& svc : builder.get_services())
     book.listen(svc->get_host_id(), svc->get_service_id(), svc.get());
 
@@ -230,17 +231,17 @@ TEST_F(BamExpBuilder, CritService2) {
 }
 
 TEST_F(BamExpBuilder, CritOkService1) {
-  config::applier::modules modules;
-  modules.load_file("./lib/10-neb.so");
+  config::applier::modules modules(_logger);
+  modules.load_file("./broker/neb/10-neb.so");
   bam::exp_parser p(
       "{host_1 service_1} {IS} {CRITICAL} {OR} {host_1 service_2} {IS} {OK}");
-  bam::hst_svc_mapping mapping;
+  bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
   mapping.set_service("host_1", "service_2", 1, 2, true);
-  bam::exp_builder builder(p.get_postfix(), mapping);
+  bam::exp_builder builder(p.get_postfix(), mapping, _logger);
   bam::bool_value::ptr b(builder.get_tree());
 
-  bam::service_book book;
+  bam::service_book book(_logger);
   for (auto& svc : builder.get_services())
     book.listen(svc->get_host_id(), svc->get_service_id(), svc.get());
 
@@ -271,17 +272,17 @@ TEST_F(BamExpBuilder, CritOkService1) {
 }
 
 TEST_F(BamExpBuilder, CritOkService2) {
-  config::applier::modules modules;
-  modules.load_file("./lib/10-neb.so");
+  config::applier::modules modules(_logger);
+  modules.load_file("./broker/neb/10-neb.so");
   bam::exp_parser p(
       "{host_1 service_1} {IS} {CRITICAL} {OR} {host_1 service_2} {IS} {OK}");
-  bam::hst_svc_mapping mapping;
+  bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
   mapping.set_service("host_1", "service_2", 1, 2, true);
-  bam::exp_builder builder(p.get_postfix(), mapping);
+  bam::exp_builder builder(p.get_postfix(), mapping, _logger);
   bam::bool_value::ptr b(builder.get_tree());
 
-  bam::service_book book;
+  bam::service_book book(_logger);
   for (auto& svc : builder.get_services())
     book.listen(svc->get_host_id(), svc->get_service_id(), svc.get());
 
@@ -319,17 +320,17 @@ TEST_F(BamExpBuilder, CritOkService2) {
 }
 
 TEST_F(BamExpBuilder, CritOkService3) {
-  config::applier::modules modules;
-  modules.load_file("./lib/10-neb.so");
+  config::applier::modules modules(_logger);
+  modules.load_file("./broker/neb/10-neb.so");
   bam::exp_parser p(
       "{host_1 service_1} {IS} {CRITICAL} {OR} {host_1 service_2} {IS} {OK}");
-  bam::hst_svc_mapping mapping;
+  bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
   mapping.set_service("host_1", "service_2", 1, 2, true);
-  bam::exp_builder builder(p.get_postfix(), mapping);
+  bam::exp_builder builder(p.get_postfix(), mapping, _logger);
   bam::bool_value::ptr b(builder.get_tree());
 
-  bam::service_book book;
+  bam::service_book book(_logger);
   for (auto& svc : builder.get_services())
     book.listen(svc->get_host_id(), svc->get_service_id(), svc.get());
 
@@ -367,17 +368,17 @@ TEST_F(BamExpBuilder, CritOkService3) {
 }
 
 TEST_F(BamExpBuilder, CritAndOkService1) {
-  config::applier::modules modules;
-  modules.load_file("./lib/10-neb.so");
+  config::applier::modules modules(_logger);
+  modules.load_file("./broker/neb/10-neb.so");
   bam::exp_parser p(
       "{host_1 service_1} {IS} {CRITICAL} {AND} {host_1 service_2} {IS} {OK}");
-  bam::hst_svc_mapping mapping;
+  bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
   mapping.set_service("host_1", "service_2", 1, 2, true);
-  bam::exp_builder builder(p.get_postfix(), mapping);
+  bam::exp_builder builder(p.get_postfix(), mapping, _logger);
   bam::bool_value::ptr b(builder.get_tree());
 
-  bam::service_book book;
+  bam::service_book book(_logger);
   for (auto& svc : builder.get_services())
     book.listen(svc->get_host_id(), svc->get_service_id(), svc.get());
 
@@ -416,17 +417,17 @@ TEST_F(BamExpBuilder, CritAndOkService1) {
 }
 
 TEST_F(BamExpBuilder, CritAndOkService2) {
-  config::applier::modules modules;
-  modules.load_file("./lib/10-neb.so");
+  config::applier::modules modules(_logger);
+  modules.load_file("./broker/neb/10-neb.so");
   bam::exp_parser p(
       "{host_1 service_1} {IS} {CRITICAL} {AND} {host_1 service_2} {IS} {OK}");
-  bam::hst_svc_mapping mapping;
+  bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
   mapping.set_service("host_1", "service_2", 1, 2, true);
-  bam::exp_builder builder(p.get_postfix(), mapping);
+  bam::exp_builder builder(p.get_postfix(), mapping, _logger);
   bam::bool_value::ptr b(builder.get_tree());
 
-  bam::service_book book;
+  bam::service_book book(_logger);
   for (auto& svc : builder.get_services())
     book.listen(svc->get_host_id(), svc->get_service_id(), svc.get());
 
@@ -464,17 +465,17 @@ TEST_F(BamExpBuilder, CritAndOkService2) {
 }
 
 TEST_F(BamExpBuilder, CritAndOkService3) {
-  config::applier::modules modules;
-  modules.load_file("./lib/10-neb.so");
+  config::applier::modules modules(_logger);
+  modules.load_file("./broker/neb/10-neb.so");
   bam::exp_parser p(
       "{host_1 service_1} {IS} {CRITICAL} {AND} {host_1 service_2} {IS} {OK}");
-  bam::hst_svc_mapping mapping;
+  bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
   mapping.set_service("host_1", "service_2", 1, 2, true);
-  bam::exp_builder builder(p.get_postfix(), mapping);
+  bam::exp_builder builder(p.get_postfix(), mapping, _logger);
   bam::bool_value::ptr b(builder.get_tree());
 
-  bam::service_book book;
+  bam::service_book book(_logger);
   for (auto& svc : builder.get_services())
     book.listen(svc->get_host_id(), svc->get_service_id(), svc.get());
 
@@ -512,15 +513,15 @@ TEST_F(BamExpBuilder, CritAndOkService3) {
 }
 
 TEST_F(BamExpBuilder, NotCritService3) {
-  config::applier::modules modules;
-  modules.load_file("./lib/10-neb.so");
+  config::applier::modules modules(_logger);
+  modules.load_file("./broker/neb/10-neb.so");
   bam::exp_parser p("({host_1 service_1} {NOT} {CRITICAL})");
-  bam::hst_svc_mapping mapping;
+  bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
-  bam::exp_builder builder(p.get_postfix(), mapping);
+  bam::exp_builder builder(p.get_postfix(), mapping, _logger);
   bam::bool_value::ptr b(builder.get_tree());
 
-  bam::service_book book;
+  bam::service_book book(_logger);
   for (auto& svc : builder.get_services())
     book.listen(svc->get_host_id(), svc->get_service_id(), svc.get());
 
@@ -548,18 +549,18 @@ TEST_F(BamExpBuilder, NotCritService3) {
 }
 
 TEST_F(BamExpBuilder, ExpressionWithService) {
-  config::applier::modules modules;
-  modules.load_file("./lib/10-neb.so");
+  config::applier::modules modules(_logger);
+  modules.load_file("./broker/neb/10-neb.so");
   bam::exp_parser p("({host_1 service_1} {NOT} {CRITICAL})");
-  bam::hst_svc_mapping mapping;
+  bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
-  bam::exp_builder builder(p.get_postfix(), mapping);
+  bam::exp_builder builder(p.get_postfix(), mapping, _logger);
   bam::bool_value::ptr b(builder.get_tree());
 
-  bam::bool_expression exp(1, true);
+  bam::bool_expression exp(1, true, _logger);
   exp.set_expression(b);
 
-  bam::service_book book;
+  bam::service_book book(_logger);
   for (auto& svc : builder.get_services())
     book.listen(svc->get_host_id(), svc->get_service_id(), svc.get());
 
@@ -587,18 +588,18 @@ TEST_F(BamExpBuilder, ExpressionWithService) {
 }
 
 TEST_F(BamExpBuilder, ReverseExpressionWithService) {
-  config::applier::modules modules;
-  modules.load_file("./lib/10-neb.so");
+  config::applier::modules modules(_logger);
+  modules.load_file("./broker/neb/10-neb.so");
   bam::exp_parser p("({host_1 service_1} {NOT} {CRITICAL})");
-  bam::hst_svc_mapping mapping;
+  bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
-  bam::exp_builder builder(p.get_postfix(), mapping);
+  bam::exp_builder builder(p.get_postfix(), mapping, _logger);
   bam::bool_value::ptr b(builder.get_tree());
 
-  bam::bool_expression exp(1, false);
+  bam::bool_expression exp(1, false, _logger);
   exp.set_expression(b);
 
-  bam::service_book book;
+  bam::service_book book(_logger);
   for (auto& svc : builder.get_services())
     book.listen(svc->get_host_id(), svc->get_service_id(), svc.get());
 
@@ -626,23 +627,24 @@ TEST_F(BamExpBuilder, ReverseExpressionWithService) {
 }
 
 TEST_F(BamExpBuilder, KpiBoolexpWithService) {
-  config::applier::modules modules;
-  modules.load_file("./lib/10-neb.so");
+  config::applier::modules modules(_logger);
+  modules.load_file("./broker/neb/10-neb.so");
   bam::exp_parser p("({host_1 service_1} {NOT} {CRITICAL})");
-  bam::hst_svc_mapping mapping;
+  bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
-  bam::exp_builder builder(p.get_postfix(), mapping);
+  bam::exp_builder builder(p.get_postfix(), mapping, _logger);
   bam::bool_value::ptr b(builder.get_tree());
 
-  auto exp = std::make_shared<bam::bool_expression>(1, true);
+  auto exp = std::make_shared<bam::bool_expression>(1, true, _logger);
   exp->set_expression(b);
   b->add_parent(exp);
 
-  auto kpi = std::make_shared<bam::kpi_boolexp>(1, 1, "test_boool_exp");
+  auto kpi =
+      std::make_shared<bam::kpi_boolexp>(1, 1, "test_boool_exp", _logger);
   kpi->link_boolexp(exp);
   exp->add_parent(kpi);
 
-  bam::service_book book;
+  bam::service_book book(_logger);
   for (auto& svc : builder.get_services())
     book.listen(svc->get_host_id(), svc->get_service_id(), svc.get());
 
@@ -670,23 +672,24 @@ TEST_F(BamExpBuilder, KpiBoolexpWithService) {
 }
 
 TEST_F(BamExpBuilder, KpiBoolexpReversedImpactWithService) {
-  config::applier::modules modules;
-  modules.load_file("./lib/10-neb.so");
+  config::applier::modules modules(_logger);
+  modules.load_file("./broker/neb/10-neb.so");
   bam::exp_parser p("({host_1 service_1} {NOT} {CRITICAL})");
-  bam::hst_svc_mapping mapping;
+  bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
-  bam::exp_builder builder(p.get_postfix(), mapping);
+  bam::exp_builder builder(p.get_postfix(), mapping, _logger);
   bam::bool_value::ptr b(builder.get_tree());
 
-  auto exp = std::make_shared<bam::bool_expression>(1, false);
+  auto exp = std::make_shared<bam::bool_expression>(1, false, _logger);
   exp->set_expression(b);
   b->add_parent(exp);
 
-  auto kpi = std::make_shared<bam::kpi_boolexp>(1, 1, "test_boool_exp");
+  auto kpi =
+      std::make_shared<bam::kpi_boolexp>(1, 1, "test_boool_exp", _logger);
   kpi->link_boolexp(exp);
   exp->add_parent(kpi);
 
-  bam::service_book book;
+  bam::service_book book(_logger);
   for (auto& svc : builder.get_services())
     book.listen(svc->get_host_id(), svc->get_service_id(), svc.get());
 
@@ -712,18 +715,18 @@ TEST_F(BamExpBuilder, KpiBoolexpReversedImpactWithService) {
 }
 
 TEST_F(BamExpBuilder, BoolexpServiceXorService) {
-  config::applier::modules modules;
-  modules.load_file("./lib/10-neb.so");
+  config::applier::modules modules(_logger);
+  modules.load_file("./broker/neb/10-neb.so");
   bam::exp_parser p(
       "({host_1 service_1} {IS} {CRITICAL}) {XOR} ({host_1 service_2} {IS} "
       "{CRITICAL})");
-  bam::hst_svc_mapping mapping;
+  bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
   mapping.set_service("host_1", "service_2", 1, 2, true);
-  bam::exp_builder builder(p.get_postfix(), mapping);
+  bam::exp_builder builder(p.get_postfix(), mapping, _logger);
   bam::bool_value::ptr b(builder.get_tree());
 
-  bam::service_book book;
+  bam::service_book book(_logger);
   for (auto& svc : builder.get_services())
     book.listen(svc->get_host_id(), svc->get_service_id(), svc.get());
 
@@ -768,16 +771,16 @@ TEST_F(BamExpBuilder, BoolexpServiceXorService) {
 }
 
 TEST_F(BamExpBuilder, BoolexpLTWithServiceStatus) {
-  config::applier::modules modules;
-  modules.load_file("./lib/10-neb.so");
+  config::applier::modules modules(_logger);
+  modules.load_file("./broker/neb/10-neb.so");
   bam::exp_parser p("{host_1 service_1} < {host_1 service_2}");
-  bam::hst_svc_mapping mapping;
+  bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
   mapping.set_service("host_1", "service_2", 1, 2, true);
-  bam::exp_builder builder(p.get_postfix(), mapping);
+  bam::exp_builder builder(p.get_postfix(), mapping, _logger);
   bam::bool_value::ptr b(builder.get_tree());
 
-  bam::service_book book;
+  bam::service_book book(_logger);
   for (auto& svc : builder.get_services())
     book.listen(svc->get_host_id(), svc->get_service_id(), svc.get());
 
@@ -822,18 +825,18 @@ TEST_F(BamExpBuilder, BoolexpLTWithServiceStatus) {
 }
 
 TEST_F(BamExpBuilder, BoolexpKpiService) {
-  config::applier::modules modules;
-  modules.load_file("./lib/10-neb.so");
+  config::applier::modules modules(_logger);
+  modules.load_file("./broker/neb/10-neb.so");
   bam::exp_parser p(
       "{host_1 service_1} {IS} {CRITICAL} {OR} {host_1 service_2} {IS} "
       "{CRITICAL}");
-  bam::hst_svc_mapping mapping;
+  bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
   mapping.set_service("host_1", "service_2", 1, 2, true);
-  bam::exp_builder builder(p.get_postfix(), mapping);
+  bam::exp_builder builder(p.get_postfix(), mapping, _logger);
   bam::bool_value::ptr b(builder.get_tree());
 
-  bam::service_book book;
+  bam::service_book book(_logger);
   for (auto& svc : builder.get_services())
     book.listen(svc->get_host_id(), svc->get_service_id(), svc.get());
 
@@ -887,34 +890,35 @@ TEST_F(BamExpBuilder, BoolexpKpiService) {
 /* Same test as BoolexpKpiService but with the point of view of a boolean
  * expression. */
 TEST_F(BamExpBuilder, BoolexpKpiServiceAndBoolExpression) {
-  config::applier::modules modules;
-  modules.load_file("./lib/10-neb.so");
+  config::applier::modules modules(_logger);
+  modules.load_file("./broker/neb/10-neb.so");
   bam::exp_parser p(
       "{host_1 service_1} {IS} {CRITICAL} {OR} {host_1 service_2} {IS} "
       "{CRITICAL}");
-  bam::hst_svc_mapping mapping;
+  bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
   mapping.set_service("host_1", "service_2", 1, 2, true);
-  bam::exp_builder builder(p.get_postfix(), mapping);
+  bam::exp_builder builder(p.get_postfix(), mapping, _logger);
   bam::bool_value::ptr b(builder.get_tree());
 
-  auto exp = std::make_shared<bam::bool_expression>(1, true);
+  auto exp = std::make_shared<bam::bool_expression>(1, true, _logger);
   exp->set_expression(b);
   b->add_parent(exp);
 
-  auto kpi = std::make_shared<bam::kpi_boolexp>(1, 1, "test_boool_exp");
+  auto kpi =
+      std::make_shared<bam::kpi_boolexp>(1, 1, "test_boool_exp", _logger);
   kpi->set_impact(100);
   kpi->link_boolexp(exp);
   exp->add_parent(kpi);
 
-  auto ba = std::make_shared<bam::ba_impact>(1, 30, 300, false);
+  auto ba = std::make_shared<bam::ba_impact>(1, 30, 300, false, _logger);
   ba->set_name("ba-kpi-service");
   ba->set_level_warning(70);
   ba->set_level_warning(80);
   ba->add_impact(kpi);
   kpi->add_parent(ba);
 
-  bam::service_book book;
+  bam::service_book book(_logger);
   for (auto& svc : builder.get_services())
     book.listen(svc->get_host_id(), svc->get_service_id(), svc.get());
 
@@ -993,34 +997,35 @@ TEST_F(BamExpBuilder, BoolexpKpiServiceAndBoolExpression) {
 /* Same test as BoolexpKpiServiceAndBoolExpression but with AND operator and
  * with impact_if set to false. */
 TEST_F(BamExpBuilder, BoolexpKpiServiceAndBoolExpressionAndOperator) {
-  config::applier::modules modules;
-  modules.load_file("./lib/10-neb.so");
+  config::applier::modules modules(_logger);
+  modules.load_file("./broker/neb/10-neb.so");
   bam::exp_parser p(
       "{host_1 service_1} {IS} {CRITICAL} {AND} {host_1 service_2} {IS} "
       "{CRITICAL}");
-  bam::hst_svc_mapping mapping;
+  bam::hst_svc_mapping mapping(_logger);
   mapping.set_service("host_1", "service_1", 1, 1, true);
   mapping.set_service("host_1", "service_2", 1, 2, true);
-  bam::exp_builder builder(p.get_postfix(), mapping);
+  bam::exp_builder builder(p.get_postfix(), mapping, _logger);
   bam::bool_value::ptr b(builder.get_tree());
 
-  auto exp = std::make_shared<bam::bool_expression>(1, false);
+  auto exp = std::make_shared<bam::bool_expression>(1, false, _logger);
   exp->set_expression(b);
   b->add_parent(exp);
 
-  auto kpi = std::make_shared<bam::kpi_boolexp>(1, 1, "test_boool_exp");
+  auto kpi =
+      std::make_shared<bam::kpi_boolexp>(1, 1, "test_boool_exp", _logger);
   kpi->set_impact(100);
   kpi->link_boolexp(exp);
   exp->add_parent(kpi);
 
-  auto ba = std::make_shared<bam::ba_impact>(1, 30, 300, false);
+  auto ba = std::make_shared<bam::ba_impact>(1, 30, 300, false, _logger);
   ba->set_name("ba-kpi-service");
   ba->set_level_warning(70);
   ba->set_level_warning(80);
   ba->add_impact(kpi);
   kpi->add_parent(ba);
 
-  bam::service_book book;
+  bam::service_book book(_logger);
   for (auto& svc : builder.get_services())
     book.listen(svc->get_host_id(), svc->get_service_id(), svc.get());
 
