@@ -1,4 +1,4 @@
-/*
+/**
  * Copyright 2011 - 2019 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -23,12 +23,9 @@
 
 using namespace com::centreon::broker;
 
-extern std::shared_ptr<asio::io_context> g_io_context;
-
 class PublisherRead : public testing::Test {
  public:
   void SetUp() override {
-    g_io_context->restart();
     config::applier::init(0, "test_broker", 0);
   }
 
