@@ -1,20 +1,20 @@
-/*
-** Copyright 2013,2015,2017, 2021 Centreon
-**
-** Licensed under the Apache License, Version 2.0 (the "License");
-** you may not use this file except in compliance with the License.
-** You may obtain a copy of the License at
-**
-**     http://www.apache.org/licenses/LICENSE-2.0
-**
-** Unless required by applicable law or agreed to in writing, software
-** distributed under the License is distributed on an "AS IS" BASIS,
-** WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-** See the License for the specific language governing permissions and
-** limitations under the License.
-**
-** For more information : contact@centreon.com
-*/
+/**
+ * Copyright 2013,2015,2017, 2021-2024 Centreon
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * For more information : contact@centreon.com
+ */
 
 #include "com/centreon/broker/bbdo/stream.hh"
 
@@ -22,6 +22,7 @@
 #include <arpa/inet.h>
 
 #include <cassert>
+#include <memory>
 
 #include "bbdo/bbdo.pb.h"
 #include "bbdo/bbdo/ack.hh"
@@ -32,15 +33,18 @@
 #include "com/centreon/broker/exceptions/timeout.hh"
 #include "com/centreon/broker/io/protocols.hh"
 #include "com/centreon/broker/io/raw.hh"
-#include "com/centreon/broker/log_v2.hh"
 #include "com/centreon/broker/misc/misc.hh"
 #include "com/centreon/broker/misc/string.hh"
+#include "com/centreon/broker/multiplexing/publisher.hh"
 #include "com/centreon/exceptions/msg_fmt.hh"
+#include "common/log_v2/log_v2.hh"
 
 using namespace com::centreon::exceptions;
 using namespace com::centreon::broker;
 using namespace com::centreon::broker::bbdo;
 
+using log_v2 = com::centreon::common::log_v2::log_v2;
+
 /**
  *  Set a boolean within an object.
  */
@@ -48,14 +52,11 @@ static uint32_t set_boolean(io::data& t,
                             mapping::entry const& member,
                             void const* data,
                             uint32_t size) {
-  if (!size) {
-    SPDLOG_LOGGER_ERROR(log_v2::bbdo(),
-                        "cannot extract boolean value: 0 bytes left in "
-                        "packet");
+  if (!size)
     throw msg_fmt(
         "cannot extract boolean value: "
         "0 bytes left in packet");
-  }
+
   member.set_bool(t, *static_cast<char const*>(data));
   return 1;
 }
@@ -69,17 +70,11 @@ static uint32_t set_double(io::data& t,
                            uint32_t size) {
   char const* str(static_cast<char const*>(data));
   uint32_t len(strlen(str));
-  if (len >= size) {
-    SPDLOG_LOGGER_ERROR(
-        log_v2::bbdo(),
-        "cannot extract double value: not terminating '\\0' in remaining "
-        "{} bytes of packet",
-        size);
+  if (len >= size)
     throw msg_fmt(
         "cannot extract double value: "
         "not terminating '\\0' in remaining {} bytes of packet",
         size);
-  }
   member.set_double(t, strtod(str, nullptr));
   return len + 1;
 }
@@ -91,15 +86,11 @@ static uint32_t set_integer(io::data& t,
                             mapping::entry const& member,
                             void const* data,
                             uint32_t size) {
-  if (size < sizeof(uint32_t)) {
-    SPDLOG_LOGGER_ERROR(log_v2::bbdo(),
-                        "cannot extract integer value: {} bytes left in packet",
-                        size);
+  if (size < sizeof(uint32_t))
     throw msg_fmt(
         "BBDO: cannot extract integer value: {}"
         " bytes left in packet",
         size);
-  }
   member.set_int(t, ntohl(*static_cast<uint32_t const*>(data)));
   return sizeof(uint32_t);
 }
@@ -111,15 +102,11 @@ static uint32_t set_short(io::data& t,
                           mapping::entry const& member,
                           void const* data,
                           uint32_t size) {
-  if (size < sizeof(uint16_t)) {
-    SPDLOG_LOGGER_ERROR(
-        log_v2::bbdo(),
-        "BBDO: cannot extract short value: {} bytes left in packet", size);
+  if (size < sizeof(uint16_t))
     throw msg_fmt(
         "BBDO: cannot extract short value: {}"
         " bytes left in packet",
         size);
-  }
   member.set_short(t, ntohs(*static_cast<uint16_t const*>(data)));
   return sizeof(uint16_t);
 }
@@ -133,18 +120,11 @@ static uint32_t set_string(io::data& t,
                            uint32_t size) {
   char const* str(static_cast<char const*>(data));
   uint32_t len(strlen(str));
-  if (len >= size) {
-    SPDLOG_LOGGER_ERROR(
-        log_v2::bbdo(),
-        "BBDO: cannot extract string value: no terminating '\\0' in remaining "
-        "{} bytes left in packet",
-        size);
-
+  if (len >= size)
     throw msg_fmt(
         "BBDO: cannot extract string value: "
         "no terminating '\\0' in remaining {} bytes of packet",
         size);
-  }
   member.set_string(t, str);
   return len + 1;
 }
@@ -156,15 +136,11 @@ static uint32_t set_timestamp(io::data& t,
                               mapping::entry const& member,
                               void const* data,
                               uint32_t size) {
-  if (size < sizeof(uint64_t)) {
-    SPDLOG_LOGGER_ERROR(
-        log_v2::bbdo(),
-        "BBDO: cannot extract timestamp value: {} bytes left in packet", size);
+  if (size < sizeof(uint64_t))
     throw msg_fmt(
         "BBDO: cannot extract timestamp value: {}"
         " bytes left in packet",
         size);
-  }
   uint32_t const* ptr(static_cast<uint32_t const*>(data));
   uint64_t val(ntohl(*ptr));
   ++ptr;
@@ -181,16 +157,11 @@ static uint32_t set_uint(io::data& t,
                          mapping::entry const& member,
                          void const* data,
                          uint32_t size) {
-  if (size < sizeof(uint32_t)) {
-    SPDLOG_LOGGER_ERROR(
-        log_v2::bbdo(),
-        "BBDO: cannot extract uint32_t integer value: {} bytes left in packet",
-        size);
+  if (size < sizeof(uint32_t))
     throw msg_fmt(
         "BBDO: cannot extract uint32_teger value: {}"
         " bytes left in packet",
         size);
-  }
   member.set_uint(t, ntohl(*static_cast<uint32_t const*>(data)));
   return sizeof(uint32_t);
 }
@@ -202,17 +173,11 @@ static uint32_t set_ulong(io::data& t,
                           mapping::entry const& member,
                           void const* data,
                           uint32_t size) {
-  if (size < sizeof(uint64_t)) {
-    SPDLOG_LOGGER_ERROR(
-        log_v2::bbdo(),
-        "BBDO: cannot extract uint64_t integer value: {} bytes left in packet",
-        size);
+  if (size < sizeof(uint64_t))
     throw msg_fmt(
         "BBDO: cannot extract uint64_teger value: {}"
         " bytes left in packet",
         size);
-  }
-
   const uint32_t* ptr(static_cast<uint32_t const*>(data));
   uint64_t val(ntohl(*ptr));
   ++ptr;
@@ -234,11 +199,11 @@ static uint32_t set_ulong(io::data& t,
  *
  *  @return Event.
  */
-static io::data* unserialize(uint32_t event_type,
-                             uint32_t source_id,
-                             uint32_t destination_id,
-                             const char* buffer,
-                             uint32_t size) {
+io::data* stream::unserialize(uint32_t event_type,
+                              uint32_t source_id,
+                              uint32_t destination_id,
+                              const char* buffer,
+                              uint32_t size) {
   // Get event info (operations and mapping).
   io::event_info const* info(io::events::instance().get_event_info(event_type));
   if (info) {
@@ -282,16 +247,13 @@ static io::data* unserialize(uint32_t event_type,
 
               default:
                 SPDLOG_LOGGER_ERROR(
-                    log_v2::bbdo(),
+                    _logger,
                     "BBDO: invalid mapping for object of type '{0}': {1} is "
-                    "not "
-                    "a known type ID",
+                    "not a known type ID",
                     info->get_name(), current_entry->get_type());
                 throw msg_fmt(
-                    "BBDO: invalid mapping for "
-                    "object of type '{}"
-                    "': {}"
-                    " is not a known type ID",
+                    "BBDO: invalid mapping for object of type '{}"
+                    "': {} is not a known type ID",
                     info->get_name(), current_entry->get_type());
             }
             buffer += rb;
@@ -300,7 +262,7 @@ static io::data* unserialize(uint32_t event_type,
         return t.release();
       } else {
         SPDLOG_LOGGER_ERROR(
-            log_v2::bbdo(),
+            _logger,
             "BBDO: cannot create object of ID {} whereas it has been "
             "registered",
             event_type);
@@ -317,7 +279,7 @@ static io::data* unserialize(uint32_t event_type,
         t->destination_id = destination_id;
       } else {
         SPDLOG_LOGGER_ERROR(
-            log_v2::bbdo(),
+            _logger,
             "BBDO: cannot create object of ID {} whereas it has been "
             "registered",
             event_type);
@@ -330,7 +292,7 @@ static io::data* unserialize(uint32_t event_type,
     }
   } else {
     SPDLOG_LOGGER_INFO(
-        log_v2::bbdo(),
+        _logger,
         "BBDO: cannot unserialize event of ID {}: event was not registered and "
         "will therefore be ignored",
         event_type);
@@ -443,7 +405,7 @@ static void get_ulong(io::data const& t,
  *
  *  @return Serialized event.
  */
-static io::raw* serialize(const io::data& e) {
+io::raw* stream::serialize(const io::data& e) {
   std::deque<std::vector<char>> queue;
 
   // Get event info (mapping).
@@ -490,7 +452,7 @@ static io::raw* serialize(const io::data& e) {
               break;
             default:
               SPDLOG_LOGGER_ERROR(
-                  log_v2::bbdo(),
+                  _logger,
                   "BBDO: invalid mapping for object of type '{}': {} is not a "
                   "known type ID",
                   info->get_name(), current_entry->get_type());
@@ -588,7 +550,7 @@ static io::raw* serialize(const io::data& e) {
     return buffer.release();
   } else {
     SPDLOG_LOGGER_INFO(
-        log_v2::bbdo(),
+        _logger,
         "BBDO: cannot serialize event of ID {}: event was not registered and "
         "will therefore be ignored",
         e.type());
@@ -598,9 +560,14 @@ static io::raw* serialize(const io::data& e) {
 }
 
 /**
- *  Default constructor.
+ * @brief Construct a new stream::stream object
+ *
+ * @param is_input true if we receive bbdo events such as broker input
+ * @param grpc_serialized true if serialization is done by grpc stream only
+ * @param extensions
  */
 stream::stream(bool is_input,
+               bool grpc_serialized,
                const std::list<std::shared_ptr<io::extension>>& extensions)
     : io::stream("BBDO"),
       _skipped(0),
@@ -613,9 +580,12 @@ stream::stream(bool is_input,
       _ack_limit(1000),
       _events_received_since_last_ack(0),
       _last_sent_ack(time(nullptr)),
+      _grpc_serialized(grpc_serialized),
       _extensions{extensions},
-      _bbdo_version(config::applier::state::instance().get_bbdo_version()) {
-  SPDLOG_LOGGER_DEBUG(log_v2::core(), "create bbdo stream {:p}",
+      _bbdo_version(config::applier::state::instance().get_bbdo_version()),
+      _logger{log_v2::instance().get(log_v2::BBDO)} {
+  SPDLOG_LOGGER_DEBUG(log_v2::instance().get(log_v2::CORE),
+                      "create bbdo stream {:p}",
                       static_cast<const void*>(this));
 }
 
@@ -624,8 +594,8 @@ stream::stream(bool is_input,
  *
  */
 stream::~stream() {
-  SPDLOG_LOGGER_DEBUG(log_v2::core(), "destroy bbdo stream {:p}",
-                      static_cast<const void*>(this));
+  SPDLOG_LOGGER_DEBUG(_logger, "destroy bbdo stream {}",
+                      static_cast<void*>(this));
 }
 
 /**
@@ -635,6 +605,7 @@ stream::~stream() {
  * @return The number of events to acknowledge.
  */
 int32_t stream::stop() {
+  _logger->trace("bbdo::stream stop {}", static_cast<void*>(this));
   /* A concrete explanation:
    * I'm engine and my work is to send data to broker.
    * Here, the user wants to stop me/ I need to ask broker how many
@@ -643,16 +614,17 @@ int32_t stream::stop() {
     try {
       _send_event_stop_and_wait_for_ack();
     } catch (const std::exception& e) {
-      log_v2::core()->info(
-          "BBDO: unable to send stop message to peer, it is already stopped: "
+      _logger->info(
+          "BBDO: unable to send stop message to peer, it is already "
+          "stopped: "
           "{}",
           e.what());
     }
   }
 
   /* We acknowledge peer about received events. */
-  log_v2::core()->info("bbdo stream stopped with {} events acknowledged",
-                       _events_received_since_last_ack);
+  _logger->info("bbdo stream stopped with {} events acknowledged",
+                _events_received_since_last_ack);
   if (_events_received_since_last_ack)
     send_event_acknowledgement();
 
@@ -684,27 +656,23 @@ int stream::flush() {
  */
 void stream::_send_event_stop_and_wait_for_ack() {
   if (!_coarse) {
-    if (_bbdo_version.major_v >= 3) {
-      SPDLOG_LOGGER_DEBUG(log_v2::bbdo(),
-                          "BBDO: sending pb stop packet to peer");
-      std::shared_ptr<bbdo::pb_stop> stop_packet{
-          std::make_shared<bbdo::pb_stop>()};
-      _write(stop_packet);
-    } else {
-      SPDLOG_LOGGER_DEBUG(log_v2::bbdo(), "BBDO: sending stop packet to peer");
-      std::shared_ptr<bbdo::stop> stop_packet{std::make_shared<bbdo::stop>()};
-      _write(stop_packet);
-    }
+    SPDLOG_LOGGER_DEBUG(_logger, "BBDO: sending stop packet to peer");
+    /* Here, we send a bbdo::pb_stop that passes through the network contrary
+     * to the local::pb_stop. */
+    std::shared_ptr<bbdo::pb_stop> stop_packet{
+        std::make_shared<bbdo::pb_stop>()};
+    stop_packet->mut_obj().set_poller_id(
+        config::applier::state::instance().poller_id());
+    _write(stop_packet);
 
-    SPDLOG_LOGGER_DEBUG(log_v2::bbdo(),
-                        "BBDO: retrieving ack packet from peer");
+    SPDLOG_LOGGER_DEBUG(_logger, "BBDO: retrieving ack packet from peer");
     std::shared_ptr<io::data> d;
     time_t deadline = time(nullptr) + 5;
 
     _read_any(d, deadline);
     if (!d) {
       SPDLOG_LOGGER_ERROR(
-          log_v2::bbdo(),
+          _logger,
           "BBDO: no message received from peer. Cannot acknowledge properly "
           "waiting messages before stopping.");
       return;
@@ -712,7 +680,7 @@ void stream::_send_event_stop_and_wait_for_ack() {
     switch (d->type()) {
       case ack::static_type():
         SPDLOG_LOGGER_INFO(
-            log_v2::bbdo(),
+            _logger,
             "BBDO: received acknowledgement for {} events before finishing",
             std::static_pointer_cast<ack const>(d)->acknowledged_events);
         acknowledge_events(
@@ -720,7 +688,7 @@ void stream::_send_event_stop_and_wait_for_ack() {
         break;
       case pb_ack::static_type():
         SPDLOG_LOGGER_INFO(
-            log_v2::bbdo(),
+            _logger,
             "BBDO: received acknowledgement for {} events before finishing",
             std::static_pointer_cast<const pb_ack>(d)
                 ->obj()
@@ -731,7 +699,7 @@ void stream::_send_event_stop_and_wait_for_ack() {
         break;
       default:
         SPDLOG_LOGGER_ERROR(
-            log_v2::bbdo(),
+            _logger,
             "BBDO: wrong message received (type {}) - expected ack event",
             d->type());
         break;
@@ -766,10 +734,10 @@ std::string stream::_get_extension_names(bool mandatory) const {
  *  @param[in] neg  Negotiation type.
  */
 void stream::negotiate(stream::negotiation_type neg) {
-  SPDLOG_LOGGER_TRACE(log_v2::bbdo(), "BBDO: negotiate");
+  SPDLOG_LOGGER_TRACE(_logger, "BBDO: negotiate");
   std::string extensions;
   if (!_negotiate) {
-    SPDLOG_LOGGER_INFO(log_v2::bbdo(), "BBDO: negotiation disabled.");
+    SPDLOG_LOGGER_INFO(_logger, "BBDO: negotiation disabled.");
     extensions = _get_extension_names(true);
   } else
     extensions = _get_extension_names(false);
@@ -779,8 +747,8 @@ void stream::negotiate(stream::negotiation_type neg) {
   // Send our own packet if we should be first.
   if (neg == negotiate_first) {
     SPDLOG_LOGGER_DEBUG(
-        log_v2::bbdo(),
-        "BBDO: sending welcome packet (available extensions: {})", extensions);
+        _logger, "BBDO: sending welcome packet (available extensions: {})",
+        extensions);
     /* if _negotiate, we send all the extensions we would like to have,
      * otherwise we only send the mandatory extensions */
     if (_bbdo_version.total_version <= v300.total_version) {
@@ -802,8 +770,7 @@ void stream::negotiate(stream::negotiation_type neg) {
   }
 
   // Read peer packet.
-  SPDLOG_LOGGER_DEBUG(log_v2::bbdo(),
-                      "BBDO: retrieving welcome packet of peer");
+  SPDLOG_LOGGER_DEBUG(_logger, "BBDO: retrieving welcome packet of peer");
   std::shared_ptr<io::data> d;
   time_t deadline;
   if (_timeout == (time_t)-1)
@@ -829,7 +796,7 @@ void stream::negotiate(stream::negotiation_type neg) {
           _bbdo_version.total_version > v300.total_version
               ? "pb_welcome"
               : "version_response");
-    SPDLOG_LOGGER_ERROR(log_v2::bbdo(), msg);
+    SPDLOG_LOGGER_ERROR(_logger, msg);
     throw msg_fmt(msg);
   }
 
@@ -837,9 +804,10 @@ void stream::negotiate(stream::negotiation_type neg) {
   if (d->type() == version_response::static_type()) {
     std::shared_ptr<version_response> v(
         std::static_pointer_cast<version_response>(d));
+    bbdo_version other_version(v->bbdo_major, v->bbdo_minor, v->bbdo_patch);
     if (v->bbdo_major != _bbdo_version.major_v) {
       SPDLOG_LOGGER_ERROR(
-          log_v2::bbdo(),
+          _logger,
           "BBDO: peer is using protocol version {}.{}.{} whereas we're using "
           "protocol version {}.{}.{}",
           v->bbdo_major, v->bbdo_minor, v->bbdo_patch, _bbdo_version.major_v,
@@ -851,7 +819,7 @@ void stream::negotiate(stream::negotiation_type neg) {
           _bbdo_version.minor_v, _bbdo_version.patch);
     }
     SPDLOG_LOGGER_INFO(
-        log_v2::bbdo(),
+        _logger,
         "BBDO: peer is using protocol version {}.{}.{}, we're using version "
         "{}.{}.{}",
         v->bbdo_major, v->bbdo_minor, v->bbdo_patch, _bbdo_version.major_v,
@@ -860,9 +828,15 @@ void stream::negotiate(stream::negotiation_type neg) {
     // Send our own packet if we should be second.
     if (neg == negotiate_second) {
       SPDLOG_LOGGER_DEBUG(
-          log_v2::bbdo(),
-          "BBDO: sending welcome packet (available extensions: {})",
+          _logger, "BBDO: sending welcome packet (available extensions: {})",
           extensions);
+      if (other_version < _bbdo_version) {
+        _bbdo_version = other_version;
+        SPDLOG_LOGGER_INFO(_logger, "bbdo version downgraded to {}.{}.{}",
+                           _bbdo_version.major_v, _bbdo_version.minor_v,
+                           _bbdo_version.patch);
+      }
+
       /* if _negotiate, we send all the extensions we would like to have,
        * otherwise we only send the mandatory extensions */
       auto welcome_packet(
@@ -874,9 +848,11 @@ void stream::negotiate(stream::negotiation_type neg) {
   } else {
     std::shared_ptr<pb_welcome> w(std::static_pointer_cast<pb_welcome>(d));
     const auto& pb_version = w->obj().version();
+    bbdo_version other_version(pb_version.major(), pb_version.minor(),
+                               pb_version.patch());
     if (pb_version.major() != _bbdo_version.major_v) {
       SPDLOG_LOGGER_ERROR(
-          log_v2::bbdo(),
+          _logger,
           "BBDO: peer is using protocol version {}.{}.{} whereas we're using "
           "protocol version {}.{}.{}",
           pb_version.major(), pb_version.minor(), pb_version.patch(),
@@ -888,7 +864,7 @@ void stream::negotiate(stream::negotiation_type neg) {
           _bbdo_version.major_v, _bbdo_version.minor_v, _bbdo_version.patch);
     }
     SPDLOG_LOGGER_INFO(
-        log_v2::bbdo(),
+        _logger,
         "BBDO: peer is using protocol version {}.{}.{}, we're using version "
         "{}.{}.{}",
         pb_version.major(), pb_version.minor(), pb_version.patch(),
@@ -897,9 +873,15 @@ void stream::negotiate(stream::negotiation_type neg) {
     // Send our own packet if we should be second.
     if (neg == negotiate_second) {
       SPDLOG_LOGGER_DEBUG(
-          log_v2::bbdo(),
-          "BBDO: sending welcome packet (available extensions: {})",
+          _logger, "BBDO: sending welcome packet (available extensions: {})",
           extensions);
+      if (other_version < _bbdo_version) {
+        _bbdo_version = other_version;
+        SPDLOG_LOGGER_INFO(_logger, "bbdo version downgraded to {}.{}.{}",
+                           _bbdo_version.major_v, _bbdo_version.minor_v,
+                           _bbdo_version.patch);
+      }
+
       /* if _negotiate, we send all the extensions we would like to have,
        * otherwise we only send the mandatory extensions */
       auto welcome(std::make_shared<pb_welcome>());
@@ -925,10 +907,9 @@ void stream::negotiate(stream::negotiation_type neg) {
 
   // Apply negotiated extensions.
   SPDLOG_LOGGER_INFO(
-      log_v2::bbdo(), "BBDO: we have extensions '{}' and peer has '{}'",
-      extensions,
+      _logger, "BBDO: we have extensions '{}' and peer has '{}'", extensions,
       fmt::string_view(peer_extensions.data(), peer_extensions.size()));
-  std::list<absl::string_view> peer_ext{absl::StrSplit(peer_extensions, ' ')};
+  std::list<std::string_view> peer_ext{absl::StrSplit(peer_extensions, ' ')};
   for (auto& ext : _extensions) {
     // Find matching extension in peer extension list.
     auto peer_it{std::find(peer_ext.begin(), peer_ext.end(), ext->name())};
@@ -936,7 +917,7 @@ void stream::negotiate(stream::negotiation_type neg) {
     if (peer_it != peer_ext.end()) {
       if (std::find(running_config.begin(), running_config.end(),
                     ext->name()) == running_config.end()) {
-        SPDLOG_LOGGER_INFO(log_v2::bbdo(), "BBDO: applying extension '{}'",
+        SPDLOG_LOGGER_INFO(_logger, "BBDO: applying extension '{}'",
                            ext->name());
         for (std::map<std::string, io::protocols::protocol>::const_iterator
                  proto_it = io::protocols::instance().begin(),
@@ -951,21 +932,20 @@ void stream::negotiate(stream::negotiation_type neg) {
           }
         }
       } else
-        SPDLOG_LOGGER_INFO(log_v2::bbdo(),
-                           "BBDO: extension '{}' already configured",
+        SPDLOG_LOGGER_INFO(_logger, "BBDO: extension '{}' already configured",
                            ext->name());
     } else {
       if (ext->is_mandatory()) {
         SPDLOG_LOGGER_ERROR(
-            log_v2::bbdo(),
+            _logger,
             "BBDO: extension '{}' is set to 'yes' in the configuration but "
             "cannot be activated because of peer configuration.",
             ext->name());
       }
       if (std::find(running_config.begin(), running_config.end(),
                     ext->name()) != running_config.end()) {
-        SPDLOG_LOGGER_INFO(log_v2::bbdo(),
-                           "BBDO: extension '{}' no more needed", ext->name());
+        SPDLOG_LOGGER_INFO(_logger, "BBDO: extension '{}' no more needed",
+                           ext->name());
         auto substream = get_substream();
         if (substream->get_name() == ext->name()) {
           auto subsubstream = substream->get_substream();
@@ -987,7 +967,7 @@ void stream::negotiate(stream::negotiation_type neg) {
   // Stream has now negotiated.
   _negotiated = true;
   config::applier::state::instance().add_poller(_poller_id, _poller_name);
-  SPDLOG_LOGGER_TRACE(log_v2::bbdo(), "Negotiation done.");
+  SPDLOG_LOGGER_TRACE(_logger, "Negotiation done.");
 }
 
 std::list<std::string> stream::get_running_config() {
@@ -1023,7 +1003,7 @@ bool stream::read(std::shared_ptr<io::data>& d, time_t deadline) {
         auto version(std::static_pointer_cast<version_response>(d));
         if (version->bbdo_major != _bbdo_version.major_v) {
           SPDLOG_LOGGER_ERROR(
-              log_v2::bbdo(),
+              _logger,
               "BBDO: peer is using protocol version {}.{}.{}, whereas we're "
               "using protocol version {}.{}.{}",
               version->bbdo_major, version->bbdo_minor, version->bbdo_patch,
@@ -1037,7 +1017,7 @@ bool stream::read(std::shared_ptr<io::data>& d, time_t deadline) {
               _bbdo_version.patch);
         }
         SPDLOG_LOGGER_INFO(
-            log_v2::bbdo(),
+            _logger,
             "BBDO: peer is using protocol version {}.{}.{} , we're using "
             "version "
             "{}.{}.{}",
@@ -1051,7 +1031,7 @@ bool stream::read(std::shared_ptr<io::data>& d, time_t deadline) {
         const auto& pb_version = welcome->obj().version();
         if (pb_version.major() != _bbdo_version.major_v) {
           SPDLOG_LOGGER_ERROR(
-              log_v2::bbdo(),
+              _logger,
               "BBDO: peer is using protocol version {}.{}.{}, whereas we're "
               "using protocol version {}.{}.{}",
               pb_version.major(), pb_version.minor(), pb_version.patch(),
@@ -1065,7 +1045,7 @@ bool stream::read(std::shared_ptr<io::data>& d, time_t deadline) {
               _bbdo_version.patch);
         }
         SPDLOG_LOGGER_INFO(
-            log_v2::bbdo(),
+            _logger,
             "BBDO: peer is using protocol version {}.{}.{} , we're using "
             "version "
             "{}.{}.{}",
@@ -1075,13 +1055,13 @@ bool stream::read(std::shared_ptr<io::data>& d, time_t deadline) {
       }
       case ack::static_type():
         SPDLOG_LOGGER_INFO(
-            log_v2::bbdo(), "BBDO: received acknowledgement for {} events",
+            _logger, "BBDO: received acknowledgement for {} events",
             std::static_pointer_cast<const ack>(d)->acknowledged_events);
         acknowledge_events(
             std::static_pointer_cast<const ack>(d)->acknowledged_events);
         break;
       case pb_ack::static_type():
-        SPDLOG_LOGGER_INFO(log_v2::bbdo(),
+        SPDLOG_LOGGER_INFO(_logger,
                            "BBDO: received pb acknowledgement for {} events",
                            std::static_pointer_cast<const pb_ack>(d)
                                ->obj()
@@ -1091,22 +1071,30 @@ bool stream::read(std::shared_ptr<io::data>& d, time_t deadline) {
                                .acknowledged_events());
         break;
       case stop::static_type(): {
-        SPDLOG_LOGGER_INFO(log_v2::bbdo(), "BBDO: received stop from peer");
+        SPDLOG_LOGGER_INFO(_logger, "BBDO: received stop from peer");
         send_event_acknowledgement();
-        break;
-      }
+      } break;
       case pb_stop::static_type(): {
-        SPDLOG_LOGGER_INFO(log_v2::bbdo(), "BBDO: received pb stop from peer");
+        SPDLOG_LOGGER_INFO(
+            _logger, "BBDO: received stop from peer with ID {}",
+            std::static_pointer_cast<pb_stop>(d)->obj().poller_id());
         send_event_acknowledgement();
-        break;
-      }
+        /* Now, we send a local::pb_stop to ask unified_sql to update the
+         * database since the poller is going away. */
+        auto loc_stop = std::make_shared<local::pb_stop>();
+        auto& obj = loc_stop->mut_obj();
+        obj.set_poller_id(
+            std::static_pointer_cast<pb_stop>(d)->obj().poller_id());
+        multiplexing::publisher pblshr;
+        pblshr.write(loc_stop);
+      } break;
       default:
         break;
     }
 
     // Control messages.
     SPDLOG_LOGGER_DEBUG(
-        log_v2::bbdo(),
+        _logger,
         "BBDO: event with ID {} was a control message, launching recursive "
         "read",
         event_id);
@@ -1120,7 +1108,7 @@ bool stream::read(std::shared_ptr<io::data>& d, time_t deadline) {
    */
   if (!timed_out) {
     ++_events_received_since_last_ack;
-    SPDLOG_LOGGER_TRACE(log_v2::bbdo(), "{} events to acknowledge",
+    SPDLOG_LOGGER_TRACE(_logger, "{} events to acknowledge",
                         _events_received_since_last_ack);
   }
   time_t now = time(nullptr);
@@ -1152,6 +1140,12 @@ bool stream::_read_any(std::shared_ptr<io::data>& d, time_t deadline) {
     for (;;) {
       /* Maybe we have to complete the header. */
       _read_packet(BBDO_HEADER_SIZE, deadline);
+      if (!_grpc_serialized_queue.empty()) {
+        d = _grpc_serialized_queue.front();
+        SPDLOG_LOGGER_TRACE(_logger, "read event: {}", *d);
+        _grpc_serialized_queue.pop_front();
+        return true;
+      }
 
       // Packet size is now at least BBDO_HEADER_SIZE and maybe contains
       // already a full BBDO packet.
@@ -1166,7 +1160,7 @@ bool stream::_read_any(std::shared_ptr<io::data>& d, time_t deadline) {
       uint16_t expected = misc::crc16_ccitt(pack + 2, BBDO_HEADER_SIZE - 2);
 
       SPDLOG_LOGGER_TRACE(
-          log_v2::bbdo(),
+          _logger,
           "Reading: header eventID {} sourceID {} destID {} checksum {:x} and "
           "expected {:x}",
           event_id, source_id, dest_id, chksum, expected);
@@ -1176,7 +1170,7 @@ bool stream::_read_any(std::shared_ptr<io::data>& d, time_t deadline) {
         if (_skipped == 0) {
           // First corrupted byte.
           SPDLOG_LOGGER_ERROR(
-              log_v2::bbdo(),
+              _logger,
               "peer {} is sending corrupted data: invalid CRC: {:04x} != "
               "{:04x}",
               peer(), chksum, expected);
@@ -1186,7 +1180,7 @@ bool stream::_read_any(std::shared_ptr<io::data>& d, time_t deadline) {
         continue;
       } else if (_skipped) {
         SPDLOG_LOGGER_INFO(
-            log_v2::bbdo(),
+            _logger,
             "peer {} sent {} corrupted payload bytes, resuming processing",
             peer(), _skipped);
         _skipped = 0;
@@ -1195,13 +1189,13 @@ bool stream::_read_any(std::shared_ptr<io::data>& d, time_t deadline) {
       // It is time to finish to read the packet.
 
       _read_packet(BBDO_HEADER_SIZE + packet_size, deadline);
+
       // Now, _packet contains at least BBDO_HEADER_SIZE + packet_size bytes.
 
       std::vector<char> content;
       if (_packet.size() == BBDO_HEADER_SIZE + packet_size) {
         SPDLOG_LOGGER_TRACE(
-            log_v2::bbdo(),
-            "packet matches header + content => extracting content");
+            _logger, "packet matches header + content => extracting content");
         // We remove the header from the packet: FIXME DBR this is not
         // beautiful...
 
@@ -1220,7 +1214,7 @@ bool stream::_read_any(std::shared_ptr<io::data>& d, time_t deadline) {
         _packet.erase(_packet.begin(),
                       _packet.begin() + BBDO_HEADER_SIZE + packet_size);
         SPDLOG_LOGGER_TRACE(
-            log_v2::bbdo(),
+            _logger,
             "packet longer than header + content => splitting the whole of "
             "size {} to content of size {} and remaining of size {}",
             previous_packet_size, content.size(), _packet.size());
@@ -1243,7 +1237,7 @@ bool stream::_read_any(std::shared_ptr<io::data>& d, time_t deadline) {
         /* There is no reason to have this but no one knows. */
         if (_buffer.size() > 0) {
           SPDLOG_LOGGER_ERROR(
-              log_v2::bbdo(),
+              _logger,
               "There are still {} long BBDO packets that cannot be sent, this "
               "maybe be due to a corrupted retention file.",
               _buffer.size());
@@ -1251,7 +1245,7 @@ bool stream::_read_any(std::shared_ptr<io::data>& d, time_t deadline) {
            * oldest ones. */
           while (_buffer.size() > 3) {
             SPDLOG_LOGGER_INFO(
-                log_v2::bbdo(),
+                _logger,
                 "One too old long event part of type {} removed from memory",
                 _buffer.front().get_event_id());
             _buffer.pop_front();
@@ -1264,14 +1258,14 @@ bool stream::_read_any(std::shared_ptr<io::data>& d, time_t deadline) {
         packet_size = content.size();
         d.reset(unserialize(event_id, source_id, dest_id, pack, packet_size));
         if (d) {
-          SPDLOG_LOGGER_TRACE(log_v2::bbdo(),
+          SPDLOG_LOGGER_TRACE(_logger,
                               "unserialized {} bytes for event of type {}",
                               BBDO_HEADER_SIZE + packet_size, event_id);
         } else {
-          SPDLOG_LOGGER_WARN(log_v2::bbdo(),
+          SPDLOG_LOGGER_WARN(_logger,
                              "unknown event type {} event cannot be decoded",
                              event_id);
-          SPDLOG_LOGGER_TRACE(log_v2::bbdo(), "discarded {} bytes",
+          SPDLOG_LOGGER_TRACE(_logger, "discarded {} bytes",
                               BBDO_HEADER_SIZE + packet_size);
         }
         return true;
@@ -1295,7 +1289,7 @@ bool stream::_read_any(std::shared_ptr<io::data>& d, time_t deadline) {
         /* There is no reason to have this but no one knows. */
         if (_buffer.size() > 1) {
           SPDLOG_LOGGER_ERROR(
-              log_v2::bbdo(),
+              _logger,
               "There are {} long BBDO packets waiting for their missing parts "
               "in memory, this may be due to a corrupted retention file.",
               _buffer.size());
@@ -1303,7 +1297,7 @@ bool stream::_read_any(std::shared_ptr<io::data>& d, time_t deadline) {
            * oldest ones. */
           while (_buffer.size() > 4) {
             SPDLOG_LOGGER_INFO(
-                log_v2::bbdo(),
+                _logger,
                 "One too old long event part of type {} removed from memory",
                 _buffer.front().get_event_id());
             _buffer.pop_front();
@@ -1324,6 +1318,8 @@ bool stream::_read_any(std::shared_ptr<io::data>& d, time_t deadline) {
  * just not finished, and so no data are lost. Received packets are BBDO packets
  * or maybe pieces of BBDO packets, so we keep vectors as is because usually a
  * vector should just represent a packet.
+ * In case of event serialized only by grpc stream, we store it in
+ * _grpc_serialized_queue
  *
  * @param size The wanted final size
  * @param deadline A time_t.
@@ -1334,18 +1330,24 @@ void stream::_read_packet(size_t size, time_t deadline) {
     std::shared_ptr<io::data> d;
     bool timeout = !_substream->read(d, deadline);
 
-    if (d && d->type() == io::raw::static_type()) {
-      std::vector<char>& new_v = std::static_pointer_cast<io::raw>(d)->_buffer;
-      if (!new_v.empty()) {
-        if (_packet.size() == 0) {
-          _packet = std::move(new_v);
-          new_v.clear();
-        } else
-          _packet.insert(_packet.end(), new_v.begin(), new_v.end());
+    if (d) {
+      if (d->type() == io::raw::static_type()) {
+        std::vector<char>& new_v =
+            std::static_pointer_cast<io::raw>(d)->_buffer;
+        if (!new_v.empty()) {
+          if (_packet.size() == 0) {
+            _packet = std::move(new_v);
+            new_v.clear();
+          } else
+            _packet.insert(_packet.end(), new_v.begin(), new_v.end());
+        }
+      } else {
+        _grpc_serialized_queue.push_back(d);
+        return;
       }
     }
     if (timeout) {
-      SPDLOG_LOGGER_TRACE(log_v2::bbdo(),
+      SPDLOG_LOGGER_TRACE(_logger,
                           "_read_packet timeout!!, size = {}, deadline = {}",
                           size, deadline);
       throw exceptions::timeout();
@@ -1407,14 +1409,17 @@ void stream::statistics(nlohmann::json& tree) const {
 void stream::_write(const std::shared_ptr<io::data>& d) {
   assert(d);
 
-  // Check if data exists.
-  std::shared_ptr<io::raw> serialized(serialize(*d));
-  if (serialized) {
-    SPDLOG_LOGGER_TRACE(log_v2::bbdo(),
-                        "BBDO: serialized event of type {} to {} bytes",
-                        d->type(), serialized->size());
-    _substream->write(serialized);
-  }
+  if (!_grpc_serialized || !std::dynamic_pointer_cast<io::protobuf_base>(d)) {
+    // Check if data exists.
+    std::shared_ptr<io::raw> serialized(serialize(*d));
+    if (serialized) {
+      SPDLOG_LOGGER_TRACE(_logger,
+                          "BBDO: serialized event of type {} to {} bytes",
+                          d->type(), serialized->size());
+      _substream->write(serialized);
+    }
+  } else
+    _substream->write(d);
 }
 
 /**
@@ -1446,17 +1451,14 @@ void stream::acknowledge_events(uint32_t events) {
  */
 void stream::send_event_acknowledgement() {
   if (!_coarse) {
+    SPDLOG_LOGGER_DEBUG(_logger, "send acknowledgement for {} events",
+                        _events_received_since_last_ack);
     if (_bbdo_version.total_version >= 0x0300000001) {
-      SPDLOG_LOGGER_DEBUG(log_v2::core(),
-                          "send pb acknowledgement for {} events",
-                          _events_received_since_last_ack);
       std::shared_ptr<pb_ack> acknowledgement(std::make_shared<pb_ack>());
       acknowledgement->mut_obj().set_acknowledged_events(
           _events_received_since_last_ack);
       _write(acknowledgement);
     } else {
-      SPDLOG_LOGGER_DEBUG(log_v2::core(), "send acknowledgement for {} events",
-                          _events_received_since_last_ack);
       std::shared_ptr<ack> acknowledgement(
           std::make_shared<ack>(_events_received_since_last_ack));
       _write(acknowledgement);
