@@ -1,4 +1,4 @@
-/*
+/**
  * Copyright 2011 - 2022-2023 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -25,7 +25,6 @@
 
 #include "com/centreon/broker/config/applier/init.hh"
 #include "com/centreon/broker/config/applier/modules.hh"
-#include "com/centreon/broker/log_v2.hh"
 #include "com/centreon/broker/neb/custom_variable.hh"
 #include "com/centreon/broker/neb/downtime.hh"
 #include "com/centreon/broker/neb/host.hh"
@@ -44,17 +43,16 @@
 #include "com/centreon/broker/sql/mysql_multi_insert.hh"
 #include "com/centreon/broker/sql/query_preparator.hh"
 #include "com/centreon/exceptions/msg_fmt.hh"
+#include "common/log_v2/log_v2.hh"
 
 using msg_fmt = com::centreon::exceptions::msg_fmt;
 using namespace com::centreon::broker;
 using namespace com::centreon::broker::database;
-
-extern std::shared_ptr<asio::io_context> g_io_context;
+using log_v2 = com::centreon::common::log_v2::log_v2;
 
 class DatabaseStorageTest : public ::testing::Test {
  public:
   void SetUp() override {
-    g_io_context->restart();
     try {
       config::applier::init(0, "test_broker", 0);
     } catch (std::exception const& e) {
@@ -506,8 +504,8 @@ TEST_F(DatabaseStorageTest, ConnectionOk) {
 // }
 //
 TEST_F(DatabaseStorageTest, CustomVarStatement) {
-  config::applier::modules modules;
-  modules.load_file("./lib/10-neb.so");
+  config::applier::modules modules(log_v2::instance().get(log_v2::SQL));
+  modules.load_file("./broker/neb/10-neb.so");
   database_config db_cfg("MySQL", "127.0.0.1", MYSQL_SOCKET, 3306, "root",
                          "centreon", "centreon_storage", 5, true, 5);
   std::unique_ptr<mysql> ms(new mysql(db_cfg));
@@ -1365,7 +1363,7 @@ TEST_F(DatabaseStorageTest, CheckBulkStatement) {
                          "centreon", "centreon_storage", 5, true, 5);
   auto ms{std::make_unique<mysql>(db_cfg)};
   std::string version = ms->get_server_version();
-  std::vector<absl::string_view> arr =
+  std::vector<std::string_view> arr =
       absl::StrSplit(version, absl::ByAnyChar(".-"));
   ASSERT_TRUE(arr.size() >= 4u);
   uint32_t major;
@@ -1374,7 +1372,7 @@ TEST_F(DatabaseStorageTest, CheckBulkStatement) {
   EXPECT_TRUE(absl::SimpleAtoi(arr[0], &major));
   EXPECT_TRUE(absl::SimpleAtoi(arr[1], &minor));
   EXPECT_TRUE(absl::SimpleAtoi(arr[2], &patch));
-  absl::string_view server_name(arr[3]);
+  std::string_view server_name(arr[3]);
   if (ms->support_bulk_statement()) {
     std::string query1{"DROP TABLE IF EXISTS ut_test"};
     std::string query2{
@@ -2081,7 +2079,7 @@ TEST_F(DatabaseStorageTest, MySqlMultiInsert) {
   ms->commit();
   std::chrono::system_clock::time_point end_insert =
       std::chrono::system_clock::now();
-  SPDLOG_LOGGER_INFO(log_v2::sql(),
+  SPDLOG_LOGGER_INFO(log_v2::instance().get(log_v2::SQL),
                      " insert {} rows in {} requests duration: {} seconds",
                      data_index, nb_request,
                      std::chrono::duration_cast<std::chrono::seconds>(
@@ -2131,7 +2129,7 @@ TEST_F(DatabaseStorageTest, MySqlMultiInsert) {
   nb_request = inserter2.execute_queries(*ms);
   ms->commit();
   end_insert = std::chrono::system_clock::now();
-  SPDLOG_LOGGER_INFO(log_v2::sql(),
+  SPDLOG_LOGGER_INFO(log_v2::instance().get(log_v2::SQL),
                      " insert {} rows in {} requests duration: {} seconds",
                      data_index, nb_request,
                      std::chrono::duration_cast<std::chrono::seconds>(
@@ -2221,10 +2219,12 @@ TEST_F(DatabaseStorageTest, bulk_or_multi_bbdo_event_bulk) {
   inserter->execute(*ms);
   ms->commit();
 
-  log_v2::sql()->info("100000 rows inserted in {} ms",
-                      std::chrono::duration_cast<std::chrono::milliseconds>(
-                          std::chrono::system_clock::now() - begin)
-                          .count());
+  log_v2::instance()
+      .get(log_v2::SQL)
+      ->info("100000 rows inserted in {} ms",
+             std::chrono::duration_cast<std::chrono::milliseconds>(
+                 std::chrono::system_clock::now() - begin)
+                 .count());
 
   std::promise<mysql_result> select_prom;
   std::future<mysql_result> select_fut = select_prom.get_future();
@@ -2272,10 +2272,12 @@ TEST_F(DatabaseStorageTest, bulk_or_multi_bbdo_event_multi) {
   inserter->execute(*ms);
   ms->commit();
 
-  log_v2::sql()->info("100000 rows inserted in {} ms",
-                      std::chrono::duration_cast<std::chrono::milliseconds>(
-                          std::chrono::system_clock::now() - begin)
-                          .count());
+  log_v2::instance()
+      .get(log_v2::SQL)
+      ->info("100000 rows inserted in {} ms",
+             std::chrono::duration_cast<std::chrono::milliseconds>(
+                 std::chrono::system_clock::now() - begin)
+                 .count());
 
   std::promise<mysql_result> select_prom;
   std::future<mysql_result> select_fut = select_prom.get_future();
