@@ -1,24 +1,23 @@
-/*
-** Copyright 2009-2022 Centreon
-**
-** Licensed under the Apache License, Version 2.0 (the "License");
-** you may not use this file except in compliance with the License.
-** You may obtain a copy of the License at
-**
-**     http://www.apache.org/licenses/LICENSE-2.0
-**
-** Unless required by applicable law or agreed to in writing, software
-** distributed under the License is distributed on an "AS IS" BASIS,
-** WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-** See the License for the specific language governing permissions and
-** limitations under the License.
-**
-** For more information : contact@centreon.com
-*/
+/**
+ * Copyright 2009-2024 Centreon
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * For more information : contact@centreon.com
+ */
 
 #include "com/centreon/broker/neb/initial.hh"
 #include "com/centreon/broker/config/applier/state.hh"
-#include "com/centreon/broker/log_v2.hh"
 #include "com/centreon/broker/neb/callbacks.hh"
 #include "com/centreon/broker/neb/events.hh"
 #include "com/centreon/broker/neb/internal.hh"
@@ -58,7 +57,7 @@ typedef int (*neb_sender)(int, void*);
 static void send_custom_variables_list(
     neb_sender sender = neb::callback_custom_variable) {
   // Start log message.
-  log_v2::neb()->info("init: beginning custom variables dump");
+  neb_logger->info("init: beginning custom variables dump");
 
   // Iterate through all hosts.
   for (host_map::iterator it{com::centreon::engine::host::hosts.begin()},
@@ -77,7 +76,7 @@ static void send_custom_variables_list(
         nscvd.type = NEBTYPE_HOSTCUSTOMVARIABLE_ADD;
         nscvd.timestamp.tv_sec = time(nullptr);
         nscvd.var_name = const_cast<char*>(name.c_str());
-        nscvd.var_value = const_cast<char*>(cit->second.get_value().c_str());
+        nscvd.var_value = const_cast<char*>(cit->second.value().c_str());
         nscvd.object_ptr = it->second.get();
 
         // Callback.
@@ -104,7 +103,7 @@ static void send_custom_variables_list(
         nscvd.type = NEBTYPE_SERVICECUSTOMVARIABLE_ADD;
         nscvd.timestamp.tv_sec = time(nullptr);
         nscvd.var_name = const_cast<char*>(name.c_str());
-        nscvd.var_value = const_cast<char*>(cit->second.get_value().c_str());
+        nscvd.var_value = const_cast<char*>(cit->second.value().c_str());
         nscvd.object_ptr = it->second.get();
 
         // Callback.
@@ -114,7 +113,7 @@ static void send_custom_variables_list(
   }
 
   // End log message.
-  log_v2::neb()->info("init: end of custom variables dump");
+  neb_logger->info("init: end of custom variables dump");
 }
 
 static void send_pb_custom_variables_list() {
@@ -124,9 +123,9 @@ static void send_pb_custom_variables_list() {
 /**
  *  Send to the global publisher the list of downtimes.
  */
-static void send_downtimes_list() {
+static void send_downtimes_list(neb_sender sender = neb::callback_downtime) {
   // Start log message.
-  log_v2::neb()->info("init: beginning downtimes dump");
+  neb_logger->info("init: beginning downtimes dump");
 
   std::multimap<
       time_t,
@@ -160,19 +159,27 @@ static void send_downtimes_list() {
     nsdd.downtime_id = p.second->get_downtime_id();
 
     // Callback.
-    neb::callback_downtime(NEBCALLBACK_DOWNTIME_DATA, &nsdd);
+    sender(NEBCALLBACK_DOWNTIME_DATA, &nsdd);
   }
 
   // End log message.
-  log_v2::neb()->info("init: end of downtimes dump");
+  neb_logger->info("init: end of downtimes dump");
+}
+
+/**
+ *  Send to the global publisher the list of downtimes.
+ */
+static void send_pb_downtimes_list() {
+  send_downtimes_list(neb::callback_pb_downtime);
 }
 
 /**
  *  Send to the global publisher the list of host dependencies within Nagios.
  */
-static void send_host_dependencies_list() {
+static void send_host_dependencies_list(
+    neb_sender callbackfct = neb::callback_dependency) {
   // Start log message.
-  log_v2::neb()->info("init: beginning host dependencies dump");
+  neb_logger->info("init: beginning host dependencies dump");
 
   try {
     // Loop through all dependencies.
@@ -188,28 +195,34 @@ static void send_host_dependencies_list() {
       nsadd.object_ptr = it->second.get();
 
       // Callback.
-      neb::callback_dependency(NEBCALLBACK_ADAPTIVE_DEPENDENCY_DATA, &nsadd);
+      callbackfct(NEBCALLBACK_ADAPTIVE_DEPENDENCY_DATA, &nsadd);
     }
   } catch (std::exception const& e) {
-    log_v2::neb()->info(
-        "init: error occurred while dumping host dependencies: {}", e.what());
+    neb_logger->info("init: error occurred while dumping host dependencies: {}",
+                     e.what());
   } catch (...) {
-    log_v2::neb()->error(
+    neb_logger->error(
         "init: unknown error occurred while dumping host dependencies");
   }
 
   // End log message.
-  log_v2::neb()->info("init: end of host dependencies dump");
+  neb_logger->info("init: end of host dependencies dump");
 
   return;
 }
 
+static void send_pb_host_dependencies_list() {
+  send_host_dependencies_list(neb::callback_pb_dependency);
+}
+
 /**
  *  Send to the global publisher the list of host groups within Engine.
  */
-static void send_host_group_list() {
+static void send_host_group_list(
+    neb_sender group_sender = neb::callback_group,
+    neb_sender group_member_sender = neb::callback_group_member) {
   // Start log message.
-  log_v2::neb()->info("init: beginning host group dump");
+  neb_logger->info("init: beginning host group dump");
 
   // Loop through all host groups.
   for (hostgroup_map::const_iterator
@@ -223,7 +236,7 @@ static void send_host_group_list() {
     nsgd.object_ptr = it->second.get();
 
     // Callback.
-    neb::callback_group(NEBCALLBACK_GROUP_DATA, &nsgd);
+    group_sender(NEBCALLBACK_GROUP_DATA, &nsgd);
 
     // Dump host group members.
     for (host_map_unsafe::const_iterator hit{it->second->members.begin()},
@@ -237,12 +250,16 @@ static void send_host_group_list() {
       nsgmd.group_ptr = it->second.get();
 
       // Callback.
-      neb::callback_group_member(NEBCALLBACK_GROUP_MEMBER_DATA, &nsgmd);
+      group_member_sender(NEBCALLBACK_GROUP_MEMBER_DATA, &nsgmd);
     }
   }
 
   // End log message.
-  log_v2::neb()->info("init: end of host group dump");
+  neb_logger->info("init: end of host group dump");
+}
+
+static void send_pb_host_group_list() {
+  send_host_group_list(neb::callback_pb_group, neb::callback_pb_group_member);
 }
 
 /**
@@ -250,7 +267,7 @@ static void send_host_group_list() {
  */
 static void send_severity_list() {
   /* Start log message. */
-  log_v2::neb()->info("init: beginning severity dump");
+  neb_logger->info("init: beginning severity dump");
 
   for (auto it = com::centreon::engine::severity::severities.begin(),
             end = com::centreon::engine::severity::severities.end();
@@ -264,7 +281,7 @@ static void send_severity_list() {
  */
 static void send_tag_list() {
   /* Start log message. */
-  log_v2::neb()->info("init: beginning tag dump");
+  neb_logger->info("init: beginning tag dump");
 
   for (auto it = com::centreon::engine::tag::tags.begin(),
             end = com::centreon::engine::tag::tags.end();
@@ -278,7 +295,7 @@ static void send_tag_list() {
  */
 static void send_host_list(neb_sender sender = neb::callback_host) {
   // Start log message.
-  log_v2::neb()->info("init: beginning host dump");
+  neb_logger->info("init: beginning host dump");
 
   // Loop through all hosts.
   for (host_map::iterator it{com::centreon::engine::host::hosts.begin()},
@@ -296,7 +313,7 @@ static void send_host_list(neb_sender sender = neb::callback_host) {
   }
 
   // End log message.
-  log_v2::neb()->info("init: end of host dump");
+  neb_logger->info("init: end of host dump");
 }
 
 /**
@@ -309,9 +326,9 @@ static void send_pb_host_list() {
 /**
  *  Send to the global publisher the list of host parents within Nagios.
  */
-static void send_host_parents_list() {
+static void send_host_parents_list(neb_sender sender = neb::callback_relation) {
   // Start log message.
-  log_v2::neb()->info("init: beginning host parents dump");
+  neb_logger->info("init: beginning host parents dump");
 
   try {
     // Loop through all hosts.
@@ -319,39 +336,45 @@ static void send_host_parents_list() {
          end{com::centreon::engine::host::hosts.end()};
          it != end; ++it) {
       // Loop through all parents.
-      for (host_map_unsafe::iterator pit{it->second->parent_hosts.begin()},
-           pend{it->second->parent_hosts.end()};
-           pit != pend; ++pit) {
+      for (auto [_, sptr_host] : it->second->parent_hosts) {
         // Fill callback struct.
         nebstruct_relation_data nsrd;
         memset(&nsrd, 0, sizeof(nsrd));
         nsrd.type = NEBTYPE_PARENT_ADD;
-        nsrd.hst = pit->second;
+        nsrd.hst = sptr_host.get();
         nsrd.dep_hst = it->second.get();
 
         // Callback.
-        neb::callback_relation(NEBTYPE_PARENT_ADD, &nsrd);
+        sender(NEBTYPE_PARENT_ADD, &nsrd);
       }
     }
   } catch (std::exception const& e) {
-    log_v2::neb()->error("init: error occurred while dumping host parents: {}",
-                         e.what());
+    neb_logger->error("init: error occurred while dumping host parents: {}",
+                      e.what());
   } catch (...) {
-    log_v2::neb()->error(
+    neb_logger->error(
         "init: unknown error occurred while dumping host parents");
   }
 
   // End log message.
-  log_v2::neb()->info("init: end of host parents dump");
+  neb_logger->info("init: end of host parents dump");
+}
+
+/**
+ *  Send to the global publisher the list of host parents within Nagios.
+ */
+static void send_pb_host_parents_list() {
+  send_host_parents_list(neb::callback_pb_relation);
 }
 
 /**
  *  Send to the global publisher the list of service dependencies within
  *  Nagios.
  */
-static void send_service_dependencies_list() {
+static void send_service_dependencies_list(
+    neb_sender sender_fct = neb::callback_dependency) {
   // Start log message.
-  log_v2::neb()->info("init: beginning service dependencies dump");
+  neb_logger->info("init: beginning service dependencies dump");
 
   try {
     // Loop through all dependencies.
@@ -368,27 +391,33 @@ static void send_service_dependencies_list() {
       nsadd.object_ptr = it->second.get();
 
       // Callback.
-      neb::callback_dependency(NEBCALLBACK_ADAPTIVE_DEPENDENCY_DATA, &nsadd);
+      sender_fct(NEBCALLBACK_ADAPTIVE_DEPENDENCY_DATA, &nsadd);
     }
   } catch (std::exception const& e) {
-    log_v2::neb()->error(
+    neb_logger->error(
         "init: error occurred while dumping service dependencies: {}",
         e.what());
   } catch (...) {
-    log_v2::neb()->error(
+    neb_logger->error(
         "init: unknown error occurred while dumping service dependencies");
   }
 
   // End log message.
-  log_v2::neb()->info("init: end of service dependencies dump");
+  neb_logger->info("init: end of service dependencies dump");
+}
+
+static void send_pb_service_dependencies_list() {
+  send_service_dependencies_list(neb::callback_pb_dependency);
 }
 
 /**
  *  Send to the global publisher the list of service groups within Engine.
  */
-static void send_service_group_list() {
+static void send_service_group_list(
+    neb_sender group_sender = neb::callback_group,
+    neb_sender group_member_sender = neb::callback_group_member) {
   // Start log message.
-  log_v2::neb()->info("init: beginning service group dump");
+  neb_logger->info("init: beginning service group dump");
 
   // Loop through all service groups.
   for (servicegroup_map::const_iterator
@@ -402,7 +431,7 @@ static void send_service_group_list() {
     nsgd.object_ptr = it->second.get();
 
     // Callback.
-    neb::callback_group(NEBCALLBACK_GROUP_DATA, &nsgd);
+    group_sender(NEBCALLBACK_GROUP_DATA, &nsgd);
 
     // Dump service group members.
     for (service_map_unsafe::const_iterator sit{it->second->members.begin()},
@@ -416,12 +445,17 @@ static void send_service_group_list() {
       nsgmd.group_ptr = it->second.get();
 
       // Callback.
-      neb::callback_group_member(NEBCALLBACK_GROUP_MEMBER_DATA, &nsgmd);
+      group_member_sender(NEBCALLBACK_GROUP_MEMBER_DATA, &nsgmd);
     }
   }
 
   // End log message.
-  log_v2::neb()->info("init: end of service groups dump");
+  neb_logger->info("init: end of service groups dump");
+}
+
+static void send_pb_service_group_list() {
+  send_service_group_list(neb::callback_pb_group,
+                          neb::callback_pb_group_member);
 }
 
 /**
@@ -429,7 +463,7 @@ static void send_service_group_list() {
  */
 static void send_service_list(neb_sender sender = neb::callback_service) {
   // Start log message.
-  log_v2::neb()->info("init: beginning service dump");
+  neb_logger->info("init: beginning service dump");
 
   // Loop through all services.
   for (service_map::const_iterator
@@ -448,7 +482,7 @@ static void send_service_list(neb_sender sender = neb::callback_service) {
   }
 
   // End log message.
-  log_v2::neb()->info("init: end of services dump");
+  neb_logger->info("init: end of services dump");
 }
 
 /**
@@ -462,8 +496,10 @@ static void send_pb_service_list() {
  *  Send the instance configuration loaded event.
  */
 static void send_instance_configuration() {
-  log_v2::neb()->info(
-      "init: sending initial instance configuration loading event");
+  neb_logger->info(
+      "init: sending initial instance configuration loading event, poller id: "
+      "{}",
+      config::applier::state::instance().poller_id());
   std::shared_ptr<neb::instance_configuration> ic(
       new neb::instance_configuration);
   ic->loaded = true;
@@ -471,6 +507,18 @@ static void send_instance_configuration() {
   neb::gl_publisher.write(ic);
 }
 
+/**
+ *  Send the instance configuration loaded event.
+ */
+static void send_pb_instance_configuration() {
+  neb_logger->info(
+      "init: sending initial instance configuration loading event");
+  auto ic = std::make_shared<neb::pb_instance_configuration>();
+  ic->mut_obj().set_loaded(true);
+  ic->mut_obj().set_poller_id(config::applier::state::instance().poller_id());
+  neb::gl_publisher.write(ic);
+}
+
 /**************************************
  *                                     *
  *          Global Functions           *
@@ -481,6 +529,7 @@ static void send_instance_configuration() {
  *  Send initial configuration to the global publisher.
  */
 void neb::send_initial_configuration() {
+  SPDLOG_LOGGER_INFO(neb_logger, "init: send poller conf");
   send_severity_list();
   send_tag_list();
   send_host_list();
@@ -505,16 +554,17 @@ void neb::send_initial_configuration() {
  *  Send initial configuration to the global publisher.
  */
 void neb::send_initial_pb_configuration() {
+  SPDLOG_LOGGER_INFO(neb_logger, "init: send poller pb conf");
   send_severity_list();
   send_tag_list();
   send_pb_host_list();
   send_pb_service_list();
   send_pb_custom_variables_list();
-  send_downtimes_list();
-  send_host_parents_list();
-  send_host_group_list();
-  send_service_group_list();
-  send_host_dependencies_list();
-  send_service_dependencies_list();
-  send_instance_configuration();
+  send_pb_downtimes_list();
+  send_pb_host_parents_list();
+  send_pb_host_group_list();
+  send_pb_service_group_list();
+  send_pb_host_dependencies_list();
+  send_pb_service_dependencies_list();
+  send_pb_instance_configuration();
 }
