@@ -1,27 +1,23 @@
-/*
-** Copyright 1999-2010 Ethan Galstad
-** Copyright 2011-2019 Centreon
-**
-** This file is part of Centreon Engine.
-**
-** Centreon Engine is free software: you can redistribute it and/or
-** modify it under the terms of the GNU General Public License version 2
-** as published by the Free Software Foundation.
-**
-** Centreon Engine is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-** General Public License for more details.
-**
-** You should have received a copy of the GNU General Public License
-** along with Centreon Engine. If not, see
-** <http://www.gnu.org/licenses/>.
-*/
+/**
+ * Copyright 2024 Centreon
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * For more information : contact@centreon.com
+ */
 
 #include "com/centreon/engine/checks/checker.hh"
 
-#include "com/centreon/engine/log_v2.hh"
-
 #include "com/centreon/engine/broker.hh"
 #include "com/centreon/engine/configuration/whitelist.hh"
 #include "com/centreon/engine/exceptions/error.hh"
@@ -37,7 +33,7 @@ using namespace com::centreon;
 using namespace com::centreon::engine::logging;
 using namespace com::centreon::engine::checks;
 
-checker* checker::_instance = nullptr;
+std::shared_ptr<checker> checker::_instance;
 static constexpr time_t max_check_reaper_time = 30;
 
 /**************************************
@@ -60,14 +56,11 @@ checker& checker::instance() {
 
 void checker::init(bool used_by_test) {
   if (!_instance)
-    _instance = new checker(used_by_test);
+    _instance = std::make_shared<checker>(used_by_test);
 }
 
 void checker::deinit() {
-  if (_instance) {
-    delete _instance;
-    _instance = nullptr;
-  }
+  _instance.reset();
 }
 
 void checker::clear() noexcept {
@@ -86,10 +79,10 @@ void checker::clear() noexcept {
  */
 void checker::reap() {
   engine_logger(dbg_functions, basic) << "checker::reap";
-  SPDLOG_LOGGER_TRACE(log_v2::functions(), "checker::reap()");
+  SPDLOG_LOGGER_TRACE(functions_logger, "checker::reap()");
 
   engine_logger(dbg_checks, basic) << "Starting to reap check results.";
-  SPDLOG_LOGGER_TRACE(log_v2::checks(), "Starting to reap check results.");
+  SPDLOG_LOGGER_TRACE(checks_logger, "Starting to reap check results.");
 
   // Time to start reaping.
   time_t reaper_start_time;
@@ -128,7 +121,7 @@ void checker::reap() {
       ++reaped_checks;
       engine_logger(dbg_checks, basic)
           << "Found a check result (#" << reaped_checks << ") to handle...";
-      SPDLOG_LOGGER_TRACE(log_v2::checks(),
+      SPDLOG_LOGGER_TRACE(checks_logger,
                           "Found a check result (#{}) to handle...",
                           reaped_checks);
       check_result::pointer result = _to_reap.front();
@@ -142,7 +135,7 @@ void checker::reap() {
           engine_logger(dbg_checks, more)
               << "Handling check result for service " << svc->host_id() << "/"
               << svc->service_id() << "...";
-          SPDLOG_LOGGER_DEBUG(log_v2::checks(),
+          SPDLOG_LOGGER_DEBUG(checks_logger,
                               "Handling check result for service {}/{}...",
                               svc->host_id(), svc->service_id());
           svc->handle_async_check_result(*result);
@@ -150,7 +143,7 @@ void checker::reap() {
           engine_logger(log_runtime_warning, basic)
               << "Check result queue errors for service " << svc->host_id()
               << "/" << svc->service_id() << " : " << e.what();
-          SPDLOG_LOGGER_WARN(log_v2::runtime(),
+          SPDLOG_LOGGER_WARN(runtime_logger,
                              "Check result queue errors for service {}/{} : {}",
                              svc->host_id(), svc->service_id(), e.what());
         }
@@ -162,16 +155,16 @@ void checker::reap() {
           // Process the check result->
           engine_logger(dbg_checks, more)
               << "Handling check result for host " << hst->host_id() << "...";
-          SPDLOG_LOGGER_DEBUG(log_v2::checks(),
+          SPDLOG_LOGGER_DEBUG(checks_logger,
                               "Handling check result for host {}...",
                               hst->host_id());
           hst->handle_async_check_result_3x(*result);
         } catch (std::exception const& e) {
           engine_logger(log_runtime_error, basic)
-              << "Check result queue errors for "
-              << "host " << hst->host_id() << " : " << e.what();
-          log_v2::runtime()->error("Check result queue errors for host {} : {}",
-                                   hst->host_id(), e.what());
+              << "Check result queue errors for " << "host " << hst->host_id()
+              << " : " << e.what();
+          runtime_logger->error("Check result queue errors for host {} : {}",
+                                hst->host_id(), e.what());
         }
       }
 
@@ -184,7 +177,7 @@ void checker::reap() {
             << "Breaking out of check result reaper: "
             << "max reaper time exceeded";
         SPDLOG_LOGGER_TRACE(
-            log_v2::checks(),
+            checks_logger,
             "Breaking out of check result reaper: max reaper time exceeded");
         break;
       }
@@ -194,7 +187,7 @@ void checker::reap() {
         engine_logger(dbg_checks, basic)
             << "Breaking out of check result reaper: signal encountered";
         SPDLOG_LOGGER_TRACE(
-            log_v2::checks(),
+            checks_logger,
             "Breaking out of check result reaper: signal encountered");
         break;
       }
@@ -204,7 +197,7 @@ void checker::reap() {
   // Reaping finished.
   engine_logger(dbg_checks, basic)
       << "Finished reaping " << reaped_checks << " check results";
-  SPDLOG_LOGGER_TRACE(log_v2::checks(), "Finished reaping {} check results",
+  SPDLOG_LOGGER_TRACE(checks_logger, "Finished reaping {} check results",
                       reaped_checks);
 }
 
@@ -226,7 +219,7 @@ void checker::run_sync(host* hst,
       << "checker::run: hst=" << hst << ", check_options=" << check_options
       << ", use_cached_result=" << use_cached_result
       << ", check_timestamp_horizon=" << check_timestamp_horizon;
-  SPDLOG_LOGGER_TRACE(log_v2::functions(),
+  SPDLOG_LOGGER_TRACE(functions_logger,
                       "checker::run: hst={:p}, check_options={}"
                       ", use_cached_result={}"
                       ", check_timestamp_horizon={}",
@@ -242,7 +235,7 @@ void checker::run_sync(host* hst,
 
   engine_logger(dbg_checks, basic)
       << "** Run sync check of host '" << hst->name() << "'...";
-  SPDLOG_LOGGER_TRACE(log_v2::checks(), "** Run sync check of host '{}'...",
+  SPDLOG_LOGGER_TRACE(checks_logger, "** Run sync check of host '{}'...",
                       hst->name());
 
   // Check if the host is viable now.
@@ -250,8 +243,7 @@ void checker::run_sync(host* hst,
     if (check_result_code)
       *check_result_code = hst->get_current_state();
     engine_logger(dbg_checks, basic) << "Host check is not viable at this time";
-    SPDLOG_LOGGER_TRACE(log_v2::checks(),
-                        "Host check is not viable at this time");
+    SPDLOG_LOGGER_TRACE(checks_logger, "Host check is not viable at this time");
     return;
   }
 
@@ -270,8 +262,8 @@ void checker::run_sync(host* hst,
         *check_result_code = hst->get_current_state();
       engine_logger(dbg_checks, more)
           << "* Using cached host state: " << hst->get_current_state();
-      SPDLOG_LOGGER_DEBUG(log_v2::checks(), "* Using cached host state: {}",
-                          hst->get_current_state());
+      SPDLOG_LOGGER_DEBUG(checks_logger, "* Using cached host state: {}",
+                          static_cast<uint32_t>(hst->get_current_state()));
 
       // Update statistics.
       update_check_stats(ACTIVE_ONDEMAND_HOST_CHECK_STATS, start_time.tv_sec);
@@ -283,9 +275,9 @@ void checker::run_sync(host* hst,
   // Checking starts.
   engine_logger(dbg_checks, more)
       << "* Running actual host check: old state=" << hst->get_current_state();
-  SPDLOG_LOGGER_DEBUG(log_v2::checks(),
+  SPDLOG_LOGGER_DEBUG(checks_logger,
                       "* Running actual host check: old state={}",
-                      hst->get_current_state());
+                      static_cast<uint32_t>(hst->get_current_state()));
 
   // Update statistics.
   update_check_stats(ACTIVE_ONDEMAND_HOST_CHECK_STATS, start_time.tv_sec);
@@ -334,13 +326,8 @@ void checker::run_sync(host* hst,
   // Synchronous check is done.
   engine_logger(dbg_checks, more)
       << "* Sync host check done: new state=" << hst->get_current_state();
-  SPDLOG_LOGGER_DEBUG(log_v2::checks(), "* Sync host check done: new state={}",
-                      hst->get_current_state());
-
-  // Send event broker.
-  broker_host_check(NEBTYPE_HOSTCHECK_PROCESSED, hst, checkable::check_active,
-                    nullptr,
-                    const_cast<char*>(hst->get_plugin_output().c_str()));
+  SPDLOG_LOGGER_DEBUG(checks_logger, "* Sync host check done: new state={}",
+                      static_cast<uint32_t>(hst->get_current_state()));
 }
 
 /**************************************
@@ -353,15 +340,18 @@ void checker::run_sync(host* hst,
  *  Default constructor.
  */
 checker::checker(bool used_by_test)
-    : commands::command_listener(),
-      _used_by_test(used_by_test),
-      _finished(false) {}
+    : commands::command_listener(), _used_by_test(used_by_test) {
+  SPDLOG_LOGGER_DEBUG(commands_logger, "create checker {:p}",
+                      static_cast<const void*>(this));
+}
 
 /**
  *  Default destructor.
  */
-checker::~checker() noexcept {
+checker::~checker() {
   clear();
+  SPDLOG_LOGGER_DEBUG(commands_logger, "delete checker {:p}",
+                      static_cast<const void*>(this));
 }
 
 /**
@@ -372,15 +362,14 @@ checker::~checker() noexcept {
 void checker::finished(commands::result const& res) noexcept {
   // Debug message.
   engine_logger(dbg_functions, basic) << "checker::finished: res=" << &res;
-  SPDLOG_LOGGER_TRACE(log_v2::functions(), "checker::finished: res={:p}",
-                      (void*)&res);
+  SPDLOG_LOGGER_TRACE(functions_logger, "checker::finished: res={}", res);
 
   std::unique_lock<std::mutex> lock(_mut_reap);
   auto it_id = _waiting_check_result.find(res.command_id);
   if (it_id == _waiting_check_result.end()) {
     engine_logger(log_runtime_warning, basic)
         << "command ID '" << res.command_id << "' not found";
-    SPDLOG_LOGGER_WARN(log_v2::runtime(), "command ID '{}' not found",
+    SPDLOG_LOGGER_WARN(runtime_logger, "command ID '{}' not found",
                        res.command_id);
     return;
   }
@@ -395,17 +384,16 @@ void checker::finished(commands::result const& res) noexcept {
                        .tv_usec = res.end_time.to_useconds() % 1000000ll};
 
   result->set_finish_time(tv);
-  result->set_early_timeout(res.exit_status == process::timeout);
+  result->set_early_timeout(res.exit_status == common::e_exit_status::timeout);
   result->set_return_code(res.exit_code);
-  result->set_exited_ok(res.exit_status == process::normal ||
-                        res.exit_status == process::timeout);
+  result->set_exited_ok(res.exit_status == common::e_exit_status::normal ||
+                        res.exit_status == common::e_exit_status::timeout);
   result->set_output(res.output);
 
   // Queue check result.
   lock.lock();
   _to_reap_partial.push_back(result);
   if (_used_by_test) {
-    _finished = true;
     lock.unlock();
     _finish_cond.notify_one();
   }
@@ -416,28 +404,18 @@ void checker::wait_completion(e_completion_filter filter) {
     throw std::invalid_argument("checker not in test usage");
   }
   std::unique_lock<std::mutex> lock(_mut_reap);
-  _finished = false;
   if (filter == e_completion_filter::all) {
-    _finish_cond.wait(lock, [this]() { return _finished; });
+    _finish_cond.wait(lock, [this]() { return !_to_reap_partial.empty(); });
   } else {
     check_source filt =
         filter == e_completion_filter::service ? service_check : host_check;
     _finish_cond.wait(lock, [this, filt]() {
-      if (!_finished) {
-        return false;
-      } else {
-        auto found =
-            std::find_if(_to_reap_partial.begin(), _to_reap_partial.end(),
-                         [filt](const check_result::pointer& res) {
-                           return res->get_object_check_type() == filt;
-                         });
-        if (found != _to_reap_partial.end()) {
-          return true;
-        } else {
-          _finished = false;
-          return false;
-        }
-      }
+      auto found =
+          std::find_if(_to_reap_partial.begin(), _to_reap_partial.end(),
+                       [filt](const check_result::pointer& res) {
+                         return res->get_object_check_type() == filt;
+                       });
+      return found != _to_reap_partial.end();
     });
   }
 }
@@ -452,7 +430,7 @@ void checker::wait_completion(e_completion_filter filter) {
  */
 com::centreon::engine::host::host_state checker::_execute_sync(host* hst) {
   engine_logger(dbg_functions, basic) << "checker::_execute_sync: hst=" << hst;
-  SPDLOG_LOGGER_TRACE(log_v2::functions(), "checker::_execute_sync: hst={:p}",
+  SPDLOG_LOGGER_TRACE(functions_logger, "checker::_execute_sync: hst={:p}",
                       (void*)hst);
 
   // Preamble.
@@ -464,18 +442,12 @@ com::centreon::engine::host::host_state checker::_execute_sync(host* hst) {
 
   engine_logger(dbg_checks, basic)
       << "** Executing sync check of host '" << hst->name() << "'...";
-  SPDLOG_LOGGER_TRACE(log_v2::checks(),
-                      "** Executing sync check of host '{}'...", hst->name());
+  SPDLOG_LOGGER_TRACE(checks_logger, "** Executing sync check of host '{}'...",
+                      hst->name());
 
   // Send broker event.
   timeval start_time{0, 0};
   timeval end_time{0, 0};
-  int ret(broker_host_check(NEBTYPE_HOSTCHECK_SYNC_PRECHECK, hst,
-                            checkable::check_active, nullptr, nullptr));
-
-  // Host sync check was cancelled or overriden by NEB module.
-  if ((NEBERROR_CALLBACKCANCEL == ret) || (NEBERROR_CALLBACKOVERRIDE == ret))
-    return hst->get_current_state();
 
   // Get current host macros.
   nagios_macros* macros(get_global_macros());
@@ -493,23 +465,17 @@ com::centreon::engine::host::host_state checker::_execute_sync(host* hst) {
   // Get command object.
   commands::command::pointer cmd = hst->get_check_command_ptr();
   std::string processed_cmd(cmd->process_cmd(macros));
-  const char* tmp_processed_cmd = processed_cmd.c_str();
-
-  // Send broker event.
-  broker_host_check(NEBTYPE_HOSTCHECK_RAW_START, hst, checkable::check_active,
-                    processed_cmd.c_str(),
-                    const_cast<char*>(hst->get_plugin_output().c_str()));
 
   // Debug messages.
   engine_logger(dbg_commands, more)
       << "Raw host check command: "
       << hst->get_check_command_ptr()->get_command_line();
-  SPDLOG_LOGGER_TRACE(log_v2::commands(), "Raw host check command: {}",
+  SPDLOG_LOGGER_TRACE(commands_logger, "Raw host check command: {}",
                       hst->get_check_command_ptr()->get_command_line());
 
   engine_logger(dbg_commands, more)
       << "Processed host check command: " << processed_cmd;
-  SPDLOG_LOGGER_TRACE(log_v2::commands(), "Processed host check command: {}",
+  SPDLOG_LOGGER_TRACE(commands_logger, "Processed host check command: {}",
                       processed_cmd);
 
   // Cleanup.
@@ -517,15 +483,6 @@ com::centreon::engine::host::host_state checker::_execute_sync(host* hst) {
   hst->set_long_plugin_output("");
   hst->set_perf_data("");
 
-  // Send broker event.
-  timeval start_cmd;
-  timeval end_cmd{0, 0};
-  gettimeofday(&start_cmd, nullptr);
-  broker_system_command(NEBTYPE_SYSTEM_COMMAND_START, NEBFLAG_NONE,
-                        NEBATTR_NONE, start_cmd, end_cmd, 0,
-                        config->host_check_timeout(), false, 0,
-                        tmp_processed_cmd, nullptr, nullptr);
-
   commands::result res;
 
   auto run_failure = [&](const std::string& reason) {
@@ -533,18 +490,19 @@ com::centreon::engine::host::host_state checker::_execute_sync(host* hst) {
     res.command_id = 0;
     res.end_time = timestamp::now();
     res.exit_code = service::state_unknown;
-    res.exit_status = process::normal;
+    res.exit_status = common::e_exit_status::normal;
     res.output = reason;
     res.start_time = res.end_time;
   };
 
-  if (!hst->is_whitelist_allowed(processed_cmd)) {
-    SPDLOG_LOGGER_ERROR(log_v2::commands(),
+  if (!hst->command_is_allowed_by_whitelist(processed_cmd,
+                                            checkable::CHECK_TYPE)) {
+    SPDLOG_LOGGER_ERROR(commands_logger,
                         "host {}: this command cannot be executed because of "
                         "security restrictions on the poller. A whitelist has "
                         "been defined, and it does not include this command.",
                         hst->name());
-    SPDLOG_LOGGER_DEBUG(log_v2::commands(),
+    SPDLOG_LOGGER_DEBUG(commands_logger,
                         "host {}: command not allowed by whitelist {}",
                         hst->name(), processed_cmd);
     run_failure(configuration::command_blacklist_output);
@@ -559,7 +517,7 @@ com::centreon::engine::host::host_state checker::_execute_sync(host* hst) {
           << "Error: Synchronous host check command execution failed: "
           << e.what();
       SPDLOG_LOGGER_WARN(
-          log_v2::runtime(),
+          runtime_logger,
           "Error: Synchronous host check command execution failed: {}",
           e.what());
     }
@@ -568,25 +526,11 @@ com::centreon::engine::host::host_state checker::_execute_sync(host* hst) {
   if (res.end_time >= res.start_time)
     execution_time = res.end_time.to_seconds() - res.start_time.to_seconds();
 
-  // Send broker event.
-  memset(&start_cmd, 0, sizeof(start_time));
-  start_cmd.tv_sec = res.start_time.to_seconds();
-  start_cmd.tv_usec =
-      res.start_time.to_useconds() - start_cmd.tv_sec * 1000000ull;
-  memset(&end_cmd, 0, sizeof(end_time));
-  end_cmd.tv_sec = res.end_time.to_seconds();
-  end_cmd.tv_usec = res.end_time.to_useconds() - end_cmd.tv_sec * 1000000ull;
-  broker_system_command(NEBTYPE_SYSTEM_COMMAND_END, NEBFLAG_NONE, NEBATTR_NONE,
-                        start_cmd, end_cmd, execution_time,
-                        config->host_check_timeout(),
-                        res.exit_status == process::timeout, res.exit_code,
-                        tmp_processed_cmd, res.output.c_str(), nullptr);
-
   // Cleanup.
   clear_volatile_macros_r(macros);
 
   // If the command timed out.
-  if (res.exit_status == process::timeout) {
+  if (res.exit_status == common::e_exit_status::timeout) {
     res.output = fmt::format("Host check timed out after {}  seconds",
                              config->host_check_timeout());
     engine_logger(log_runtime_warning, basic)
@@ -594,7 +538,7 @@ com::centreon::engine::host::host_state checker::_execute_sync(host* hst) {
         << hst->name() << "' timed out after " << config->host_check_timeout()
         << " seconds";
     SPDLOG_LOGGER_WARN(
-        log_v2::runtime(),
+        runtime_logger,
         "Warning: Host check command '{}' for host '{}' timed out after {} "
         "seconds",
         processed_cmd, hst->name(), config->host_check_timeout());
@@ -642,16 +586,11 @@ com::centreon::engine::host::host_state checker::_execute_sync(host* hst) {
   // Get the end time of command.
   gettimeofday(&end_time, nullptr);
 
-  // Send broker event.
-  broker_host_check(NEBTYPE_HOSTCHECK_RAW_END, hst, checkable::check_active,
-                    tmp_processed_cmd,
-                    const_cast<char*>(hst->get_plugin_output().c_str()));
-
   // Termination.
   engine_logger(dbg_checks, basic)
       << "** Sync host check done: state=" << return_result;
-  SPDLOG_LOGGER_TRACE(log_v2::checks(), "** Sync host check done: state={}",
-                      return_result);
+  SPDLOG_LOGGER_TRACE(checks_logger, "** Sync host check done: state={}",
+                      static_cast<uint32_t>(return_result));
   return return_result;
 }
 
