@@ -1,33 +1,31 @@
-/*
-** Copyright 2020-2022 Centreon
-**
-** This file is part of Centreon Engine.
-**
-** Centreon Engine is free software: you can redistribute it and/or
-** modify it under the terms of the GNU General Public License version 2
-** as published by the Free Software Foundation.
-**
-** Centreon Engine is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-** General Public License for more details.
-**
-** You should have received a copy of the GNU General Public License
-** along with Centreon Engine. If not, see
-** <http://www.gnu.org/licenses/>.
-*/
+/**
+ * Copyright 2020-2024 Centreon
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * For more information : contact@centreon.com
+ *
+ */
 
 #include "com/centreon/engine/configuration/anomalydetection.hh"
 #include <absl/strings/numbers.h>
 #include <absl/strings/str_split.h>
 #include <absl/strings/string_view.h>
-#include "com/centreon/engine/configuration/serviceextinfo.hh"
 #include "com/centreon/engine/customvariable.hh"
 #include "com/centreon/engine/exceptions/error.hh"
+#include "com/centreon/engine/globals.hh"
 #include "com/centreon/engine/host.hh"
-#include "com/centreon/engine/log_v2.hh"
 #include "com/centreon/engine/logging/logger.hh"
-#include "com/centreon/engine/string.hh"
 
 extern int config_warnings;
 extern int config_errors;
@@ -327,7 +325,7 @@ bool anomalydetection::operator==(
   if (!object::operator==(other)) {
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => object don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => object don't match");
     return false;
   }
@@ -335,7 +333,7 @@ bool anomalydetection::operator==(
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => "
            "acknowledgement_timeout don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => "
         "acknowledgement_timeout don't match");
     return false;
@@ -343,7 +341,7 @@ bool anomalydetection::operator==(
   if (_action_url != other._action_url) {
     engine_logger(dbg_config, more) << "configuration::anomalydetection::"
                                        "equality => action_url don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::"
         "equality => action_url don't match");
     return false;
@@ -351,7 +349,7 @@ bool anomalydetection::operator==(
   if (_status_change != other._status_change) {
     engine_logger(dbg_config, more) << "configuration::anomalydetection::"
                                        "equality => status_change don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::"
         "equality => status_change don't match");
     return false;
@@ -359,7 +357,7 @@ bool anomalydetection::operator==(
   if (_checks_active != other._checks_active) {
     engine_logger(dbg_config, more) << "configuration::anomalydetection::"
                                        "equality => checks_active don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::"
         "equality => checks_active don't match");
     return false;
@@ -367,7 +365,7 @@ bool anomalydetection::operator==(
   if (_checks_passive != other._checks_passive) {
     engine_logger(dbg_config, more) << "configuration::anomalydetection::"
                                        "equality => checks_passive don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::"
         "equality => checks_passive don't match");
     return false;
@@ -375,7 +373,7 @@ bool anomalydetection::operator==(
   if (_metric_name != other._metric_name) {
     engine_logger(dbg_config, more) << "configuration::anomalydetection::"
                                        "equality => metric_name don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::"
         "equality => metric_name don't match");
     return false;
@@ -384,7 +382,7 @@ bool anomalydetection::operator==(
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => thresholds_file don't "
            "match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => thresholds_file don't "
         "match");
     return false;
@@ -393,7 +391,7 @@ bool anomalydetection::operator==(
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => check_freshness don't "
            "match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => check_freshness don't "
         "match");
     return false;
@@ -401,7 +399,7 @@ bool anomalydetection::operator==(
   if (_check_interval != other._check_interval) {
     engine_logger(dbg_config, more) << "configuration::anomalydetection::"
                                        "equality => check_interval don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::"
         "equality => check_interval don't match");
     return false;
@@ -409,7 +407,7 @@ bool anomalydetection::operator==(
   if (_contactgroups != other._contactgroups) {
     engine_logger(dbg_config, more) << "configuration::anomalydetection::"
                                        "equality => contactgroups don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::"
         "equality => contactgroups don't match");
     return false;
@@ -417,7 +415,7 @@ bool anomalydetection::operator==(
   if (_contacts != other._contacts) {
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => contacts don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => contacts don't match");
     return false;
   }
@@ -425,7 +423,7 @@ bool anomalydetection::operator==(
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => customvariables don't "
            "match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => customvariables don't "
         "match");
     return false;
@@ -433,7 +431,7 @@ bool anomalydetection::operator==(
   if (_display_name != other._display_name) {
     engine_logger(dbg_config, more) << "configuration::anomalydetection::"
                                        "equality => display_name don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::"
         "equality => display_name don't match");
     return false;
@@ -441,7 +439,7 @@ bool anomalydetection::operator==(
   if (_event_handler != other._event_handler) {
     engine_logger(dbg_config, more) << "configuration::anomalydetection::"
                                        "equality => event_handler don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::"
         "equality => event_handler don't match");
     return false;
@@ -449,7 +447,7 @@ bool anomalydetection::operator==(
   if (_event_handler_enabled != other._event_handler_enabled) {
     engine_logger(dbg_config, more) << "configuration::anomalydetection::"
                                        "equality => event_handler don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::"
         "equality => event_handler don't match");
     return false;
@@ -458,7 +456,7 @@ bool anomalydetection::operator==(
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => "
            "first_notification_delay don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => "
         "first_notification_delay don't match");
     return false;
@@ -467,7 +465,7 @@ bool anomalydetection::operator==(
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => "
            "flap_detection_enabled don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => "
         "flap_detection_enabled don't match");
     return false;
@@ -476,7 +474,7 @@ bool anomalydetection::operator==(
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => "
            "flap_detection_options don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => "
         "flap_detection_options don't match");
     return false;
@@ -485,7 +483,7 @@ bool anomalydetection::operator==(
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => "
            "freshness_threshold don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => "
         "freshness_threshold don't match");
     return false;
@@ -494,7 +492,7 @@ bool anomalydetection::operator==(
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => "
            "high_flap_threshold don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => "
         "high_flap_threshold don't match");
     return false;
@@ -502,7 +500,7 @@ bool anomalydetection::operator==(
   if (_host_name != other._host_name) {
     engine_logger(dbg_config, more) << "configuration::anomalydetection::"
                                        "equality => _host_name don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::"
         "equality => _host_name don't match");
     return false;
@@ -510,7 +508,7 @@ bool anomalydetection::operator==(
   if (_icon_image != other._icon_image) {
     engine_logger(dbg_config, more) << "configuration::anomalydetection::"
                                        "equality => icon_image don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::"
         "equality => icon_image don't match");
     return false;
@@ -518,7 +516,7 @@ bool anomalydetection::operator==(
   if (_icon_image_alt != other._icon_image_alt) {
     engine_logger(dbg_config, more) << "configuration::anomalydetection::"
                                        "equality => icon_image_alt don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::"
         "equality => icon_image_alt don't match");
     return false;
@@ -526,7 +524,7 @@ bool anomalydetection::operator==(
   if (_initial_state != other._initial_state) {
     engine_logger(dbg_config, more) << "configuration::anomalydetection::"
                                        "equality => initial_state don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::"
         "equality => initial_state don't match");
     return false;
@@ -534,7 +532,7 @@ bool anomalydetection::operator==(
   if (_is_volatile != other._is_volatile) {
     engine_logger(dbg_config, more) << "configuration::anomalydetection::"
                                        "equality => is_volatile don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::"
         "equality => is_volatile don't match");
     return false;
@@ -543,7 +541,7 @@ bool anomalydetection::operator==(
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => low_flap_threshold "
            "don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => low_flap_threshold "
         "don't match");
     return false;
@@ -552,7 +550,7 @@ bool anomalydetection::operator==(
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => max_check_attempts "
            "don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => max_check_attempts "
         "don't match");
     return false;
@@ -560,14 +558,14 @@ bool anomalydetection::operator==(
   if (_notes != other._notes) {
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => notes don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => notes don't match");
     return false;
   }
   if (_notes_url != other._notes_url) {
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => notes_url don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => notes_url don't match");
     return false;
   }
@@ -575,7 +573,7 @@ bool anomalydetection::operator==(
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => "
            "notifications_enabled don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => "
         "notifications_enabled don't match");
     return false;
@@ -584,7 +582,7 @@ bool anomalydetection::operator==(
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => "
            "notification_interval don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => "
         "notification_interval don't match");
     return false;
@@ -593,7 +591,7 @@ bool anomalydetection::operator==(
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => "
            "notification_options don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => "
         "notification_options don't match");
     return false;
@@ -602,7 +600,7 @@ bool anomalydetection::operator==(
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => "
            "notification_period don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => "
         "notification_period don't match");
     return false;
@@ -611,7 +609,7 @@ bool anomalydetection::operator==(
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => "
            "obsess_over_service don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => "
         "obsess_over_service don't match");
     return false;
@@ -620,7 +618,7 @@ bool anomalydetection::operator==(
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => process_perf_data "
            "don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => process_perf_data "
         "don't match");
     return false;
@@ -629,7 +627,7 @@ bool anomalydetection::operator==(
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => "
            "retain_nonstatus_information don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => "
         "retain_nonstatus_information don't match");
     return false;
@@ -638,7 +636,7 @@ bool anomalydetection::operator==(
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => "
            "retain_status_information don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => "
         "retain_status_information don't match");
     return false;
@@ -646,7 +644,7 @@ bool anomalydetection::operator==(
   if (_retry_interval != other._retry_interval) {
     engine_logger(dbg_config, more) << "configuration::anomalydetection::"
                                        "equality => retry_interval don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::"
         "equality => retry_interval don't match");
     return false;
@@ -655,7 +653,7 @@ bool anomalydetection::operator==(
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => "
            "recovery_notification_delay don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => "
         "recovery_notification_delay don't match");
     return false;
@@ -663,7 +661,7 @@ bool anomalydetection::operator==(
   if (_servicegroups != other._servicegroups) {
     engine_logger(dbg_config, more) << "configuration::anomalydetection::"
                                        "equality => servicegroups don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::"
         "equality => servicegroups don't match");
     return false;
@@ -672,7 +670,7 @@ bool anomalydetection::operator==(
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => "
            "service_description don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => "
         "service_description don't match");
     return false;
@@ -680,27 +678,27 @@ bool anomalydetection::operator==(
   if (_host_id != other._host_id) {
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => host_id don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => host_id don't match");
     return false;
   }
   if (_host_id != other._host_id) {
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => host_id don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => host_id don't match");
     return false;
   }
   if (_service_id != other._service_id) {
     engine_logger(dbg_config, more) << "configuration::anomalydetection::"
                                        "equality => service_id don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::"
         "equality => service_id don't match");
     return false;
   }
   if (_internal_id != other._internal_id) {
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => internal_id "
         "don't match");
     return false;
@@ -709,7 +707,7 @@ bool anomalydetection::operator==(
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => dependent_service_id "
            "don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => dependent_service_id "
         "don't match");
     return false;
@@ -718,7 +716,7 @@ bool anomalydetection::operator==(
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => stalking_options "
            "don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => stalking_options "
         "don't match");
     return false;
@@ -726,41 +724,41 @@ bool anomalydetection::operator==(
   if (_timezone != other._timezone) {
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => timezone don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => timezone don't match");
     return false;
   }
   if (_severity_id != other._severity_id) {
     engine_logger(dbg_config, more) << "configuration::anomalydetection::"
                                        "equality => severity id don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => severity id don't match");
     return false;
   }
   if (_icon_id != other._icon_id) {
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => icon id don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => icon id don't match");
     return false;
   }
   if (_tags != other._tags) {
     engine_logger(dbg_config, more)
         << "configuration::anomalydetection::equality => tags don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => tags don't match");
     return false;
   }
   if (_sensitivity != other._sensitivity) {
     engine_logger(dbg_config, more) << "configuration::anomalydetection::"
                                        "equality => sensitivity don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::anomalydetection::equality => sensitivity don't match");
     return false;
   }
   engine_logger(dbg_config, more)
       << "configuration::anomalydetection::equality => OK";
-  log_v2::config()->debug("configuration::anomalydetection::equality => OK");
+  config_logger->debug("configuration::anomalydetection::equality => OK");
   return true;
 }
 
@@ -920,19 +918,6 @@ anomalydetection::key_type anomalydetection::key() const {
   return k;
 }
 
-/**
- *  Merge object.
- *
- *  @param[in] obj The object to merge.
- */
-void anomalydetection::merge(configuration::serviceextinfo const& tmpl) {
-  MRG_DEFAULT(_action_url);
-  MRG_DEFAULT(_icon_image);
-  MRG_DEFAULT(_icon_image_alt);
-  MRG_DEFAULT(_notes);
-  MRG_DEFAULT(_notes_url);
-}
-
 /**
  *  Merge object.
  *
@@ -1008,7 +993,7 @@ bool anomalydetection::parse(char const* key, char const* value) {
     return (it->second)(*this, value);
 
   if (key[0] == '_') {
-    map_customvar::iterator it{_customvariables.find(key + 1)};
+    auto it = _customvariables.find(key + 1);
     if (it == _customvariables.end())
       _customvariables[key + 1] = customvariable(value);
     else
@@ -1150,8 +1135,8 @@ bool anomalydetection::contacts_defined() const noexcept {
  *
  *  @return The customvariables.
  */
-com::centreon::engine::map_customvar const& anomalydetection::customvariables()
-    const noexcept {
+const std::unordered_map<std::string, customvariable>&
+anomalydetection::customvariables() const noexcept {
   return _customvariables;
 }
 
@@ -1160,7 +1145,7 @@ com::centreon::engine::map_customvar const& anomalydetection::customvariables()
  *
  *  @return The customvariables.
  */
-com::centreon::engine::map_customvar&
+std::unordered_map<std::string, customvariable>&
 anomalydetection::customvariables() noexcept {
   return _customvariables;
 }
@@ -1343,7 +1328,6 @@ bool anomalydetection::notifications_enabled() const noexcept {
  */
 void anomalydetection::notification_interval(unsigned int interval) noexcept {
   _notification_interval = interval;
-  return;
 }
 
 /**
@@ -1380,7 +1364,6 @@ unsigned short anomalydetection::notification_options() const noexcept {
  */
 void anomalydetection::notification_period(std::string const& period) {
   _notification_period = period;
-  return;
 }
 
 /**
@@ -1543,7 +1526,6 @@ unsigned short anomalydetection::stalking_options() const noexcept {
  */
 void anomalydetection::timezone(std::string const& time_zone) {
   _timezone = time_zone;
-  return;
 }
 
 /**
@@ -1604,7 +1586,7 @@ bool anomalydetection::set_acknowledgement_timeout(int value) {
  *
  *  @return True on success, otherwise false.
  */
-bool anomalydetection::_set_action_url(std::string const& value) {
+bool anomalydetection::_set_action_url(const std::string& value) {
   _action_url = value;
   return true;
 }
@@ -1769,7 +1751,7 @@ bool anomalydetection::_set_failure_prediction_enabled(bool value) {
   engine_logger(log_verification_error, basic)
       << "Warning: anomalydetection failure_prediction_enabled is deprecated."
       << " This option will not be supported in 20.04.";
-  log_v2::config()->warn(
+  config_logger->warn(
       "Warning: anomalydetection failure_prediction_enabled is deprecated. "
       "This option will not be supported in 20.04.");
   ++config_warnings;
@@ -1789,7 +1771,7 @@ bool anomalydetection::_set_failure_prediction_options(
   engine_logger(log_verification_error, basic)
       << "Warning: anomalydetection failure_prediction_options is deprecated."
       << " This option will not be supported in 20.04.";
-  log_v2::config()->warn(
+  config_logger->warn(
       "Warning: anomalydetection failure_prediction_options is deprecated. "
       "This option will not be supported in 20.04.");
   ++config_warnings;
@@ -1829,22 +1811,20 @@ bool anomalydetection::_set_flap_detection_enabled(bool value) {
  */
 bool anomalydetection::_set_flap_detection_options(std::string const& value) {
   unsigned short options(none);
-  std::list<std::string> values;
-  string::split(value, values, ',');
-  for (std::list<std::string>::iterator it(values.begin()), end(values.end());
-       it != end; ++it) {
-    string::trim(*it);
-    if (*it == "o" || *it == "ok")
+  auto values = absl::StrSplit(value, ',');
+  for (auto& val : values) {
+    auto v = absl::StripAsciiWhitespace(val);
+    if (v == "o" || v == "ok")
       options |= ok;
-    else if (*it == "w" || *it == "warning")
+    else if (v == "w" || v == "warning")
       options |= warning;
-    else if (*it == "u" || *it == "unknown")
+    else if (v == "u" || v == "unknown")
       options |= unknown;
-    else if (*it == "c" || *it == "critical")
+    else if (v == "c" || v == "critical")
       options |= critical;
-    else if (*it == "n" || *it == "none")
+    else if (v == "n" || v == "none")
       options = none;
-    else if (*it == "a" || *it == "all")
+    else if (v == "a" || v == "all")
       options = ok | warning | unknown | critical;
     else
       return false;
@@ -1921,8 +1901,8 @@ bool anomalydetection::_set_icon_image_alt(std::string const& value) {
  *  @return True on success, otherwise false.
  */
 bool anomalydetection::_set_initial_state(std::string const& value) {
-  std::string data(value);
-  string::trim(data);
+  std::string_view data(value);
+  data = absl::StripAsciiWhitespace(data);
   if (data == "o" || data == "ok")
     _initial_state = engine::service::state_ok;
   else if (data == "w" || data == "warning")
@@ -2019,26 +1999,24 @@ bool anomalydetection::_set_notifications_enabled(bool value) {
  */
 bool anomalydetection::_set_notification_options(std::string const& value) {
   unsigned short options(none);
-  std::list<std::string> values;
-  string::split(value, values, ',');
-  for (std::list<std::string>::iterator it(values.begin()), end(values.end());
-       it != end; ++it) {
-    string::trim(*it);
-    if (*it == "u" || *it == "unknown")
+  auto values = absl::StrSplit(value, ',');
+  for (auto& val : values) {
+    auto v = absl::StripAsciiWhitespace(val);
+    if (v == "u" || v == "unknown")
       options |= unknown;
-    else if (*it == "w" || *it == "warning")
+    else if (v == "w" || v == "warning")
       options |= warning;
-    else if (*it == "c" || *it == "critical")
+    else if (v == "c" || v == "critical")
       options |= critical;
-    else if (*it == "r" || *it == "recovery")
+    else if (v == "r" || v == "recovery")
       options |= ok;
-    else if (*it == "f" || *it == "flapping")
+    else if (v == "f" || v == "flapping")
       options |= flapping;
-    else if (*it == "s" || *it == "downtime")
+    else if (v == "s" || v == "downtime")
       options |= downtime;
-    else if (*it == "n" || *it == "none")
+    else if (v == "n" || v == "none")
       options = none;
-    else if (*it == "a" || *it == "all")
+    else if (v == "a" || v == "all")
       options = unknown | warning | critical | ok | flapping | downtime;
     else
       return false;
@@ -2095,7 +2073,7 @@ bool anomalydetection::_set_parallelize_check(bool value) {
   engine_logger(log_verification_error, basic)
       << "Warning: anomalydetection parallelize_check is deprecated"
       << " This option will not be supported in 20.04.";
-  log_v2::config()->warn(
+  config_logger->warn(
       "Warning: anomalydetection parallelize_check is deprecated This option "
       "will not be supported in 20.04.");
   ++config_warnings;
@@ -2233,22 +2211,20 @@ bool anomalydetection::set_dependent_service_id(uint64_t value) {
  */
 bool anomalydetection::_set_stalking_options(std::string const& value) {
   unsigned short options(none);
-  std::list<std::string> values;
-  string::split(value, values, ',');
-  for (std::list<std::string>::iterator it(values.begin()), end(values.end());
-       it != end; ++it) {
-    string::trim(*it);
-    if (*it == "o" || *it == "ok")
+  auto values = absl::StrSplit(value, ',');
+  for (auto& val : values) {
+    auto v = absl::StripAsciiWhitespace(val);
+    if (v == "o" || v == "ok")
       options |= ok;
-    else if (*it == "w" || *it == "warning")
+    else if (v == "w" || v == "warning")
       options |= warning;
-    else if (*it == "u" || *it == "unknown")
+    else if (v == "u" || v == "unknown")
       options |= unknown;
-    else if (*it == "c" || *it == "critical")
+    else if (v == "c" || v == "critical")
       options |= critical;
-    else if (*it == "n" || *it == "none")
+    else if (v == "n" || v == "none")
       options = none;
-    else if (*it == "a" || *it == "all")
+    else if (v == "a" || v == "all")
       options = ok | warning | unknown | critical;
     else
       return false;
@@ -2278,7 +2254,7 @@ bool anomalydetection::_set_timezone(std::string const& value) {
  */
 bool anomalydetection::_set_category_tags(const std::string& value) {
   bool ret = true;
-  std::list<absl::string_view> tags{absl::StrSplit(value, ',')};
+  std::list<std::string_view> tags{absl::StrSplit(value, ',')};
   for (std::set<std::pair<uint64_t, uint16_t>>::iterator it(_tags.begin()),
        end(_tags.end());
        it != end;) {
@@ -2295,7 +2271,7 @@ bool anomalydetection::_set_category_tags(const std::string& value) {
     if (parse_ok) {
       _tags.emplace(id, tag::servicecategory);
     } else {
-      log_v2::config()->warn(
+      config_logger->warn(
           "Warning: anomalydetection ({}, {}) error for parsing tag {}",
           _host_id, _service_id, value);
       ret = false;
@@ -2313,7 +2289,7 @@ bool anomalydetection::_set_category_tags(const std::string& value) {
  */
 bool anomalydetection::_set_group_tags(const std::string& value) {
   bool ret = true;
-  std::list<absl::string_view> tags{absl::StrSplit(value, ',')};
+  std::list<std::string_view> tags{absl::StrSplit(value, ',')};
   for (std::set<std::pair<uint64_t, uint16_t>>::iterator it(_tags.begin()),
        end(_tags.end());
        it != end;) {
@@ -2330,7 +2306,7 @@ bool anomalydetection::_set_group_tags(const std::string& value) {
     if (parse_ok) {
       _tags.emplace(id, tag::servicegroup);
     } else {
-      log_v2::config()->warn(
+      config_logger->warn(
           "Warning: anomalydetection ({}, {}) error for parsing tag {}",
           _host_id, _service_id, value);
       ret = false;
