@@ -2,7 +2,7 @@
  * Copyright 1999-2009 Ethan Galstad
  * Copyright 2009-2010 Nagios Core Development Team and Community Contributors
  * Copyright 2011-2013 Merethis
- * Copyright 2013-2022 Centreon
+ * Copyright 2013-2024 Centreon
  *
  * This file is part of Centreon Engine.
  *
@@ -21,16 +21,13 @@
  */
 
 #include "com/centreon/engine/events/loop.hh"
-#include <chrono>
 #include <future>
-#include <thread>
 #include "com/centreon/engine/broker.hh"
 #include "com/centreon/engine/command_manager.hh"
 #include "com/centreon/engine/configuration/applier/state.hh"
 #include "com/centreon/engine/configuration/extended_conf.hh"
 #include "com/centreon/engine/configuration/parser.hh"
 #include "com/centreon/engine/globals.hh"
-#include "com/centreon/engine/log_v2.hh"
 #include "com/centreon/engine/logging/logger.hh"
 #include "com/centreon/engine/statusdata.hh"
 #include "com/centreon/logging/engine.hh"
@@ -63,11 +60,11 @@ void loop::clear() {
 void loop::run() {
   // Debug message.
   engine_logger(dbg_functions, basic) << "events::loop::run()";
-  log_v2::functions()->trace("events::loop::run()");
+  functions_logger->trace("events::loop::run()");
 
   engine_logger(log_info_message, basic)
       << "Configuration loaded, main loop starting.";
-  log_v2::process()->info("Configuration loaded, main loop starting.");
+  process_logger->info("Configuration loaded, main loop starting.");
   // Initialize some time members.
   time(&_last_time);
   _last_status_update = 0L;
@@ -94,7 +91,7 @@ loop::loop() : _need_reload(0), _reload_running(false) {}
 
 static void apply_conf(std::atomic<bool>* reloading) {
   engine_logger(log_info_message, more) << "Starting to reload configuration.";
-  log_v2::process()->info("Starting to reload configuration.");
+  process_logger->info("Starting to reload configuration.");
   try {
     configuration::state config;
     {
@@ -106,14 +103,14 @@ static void apply_conf(std::atomic<bool>* reloading) {
     configuration::applier::state::instance().apply(config);
     engine_logger(log_info_message, basic)
         << "Configuration reloaded, main loop continuing.";
-    log_v2::process()->info("Configuration reloaded, main loop continuing.");
+    process_logger->info("Configuration reloaded, main loop continuing.");
   } catch (std::exception const& e) {
     engine_logger(log_config_error, most) << "Error: " << e.what();
-    log_v2::config()->error("Error: {}", e.what());
+    config_logger->error("Error: {}", e.what());
   }
   *reloading = false;
   engine_logger(log_info_message, more) << "Reload configuration finished.";
-  log_v2::process()->info("Reload configuration finished.");
+  process_logger->info("Reload configuration finished.");
 }
 
 /**
@@ -131,7 +128,7 @@ void loop::_dispatching() {
       engine_logger(log_runtime_error, basic)
           << "There aren't any events that need to be handled! "
           << "Exiting...";
-      log_v2::runtime()->error(
+      runtime_logger->error(
           "There aren't any events that need to be handled! Exiting...");
       break;
     }
@@ -145,15 +142,15 @@ void loop::_dispatching() {
     // Start reload configuration.
     if (_need_reload) {
       engine_logger(log_info_message, most) << "Need reload.";
-      log_v2::process()->info("Need reload.");
+      process_logger->info("Need reload.");
       if (!reloading) {
         engine_logger(log_info_message, most) << "Reloading...";
-        log_v2::process()->info("Reloading...");
+        process_logger->info("Reloading...");
         reloading = true;
         std::async(std::launch::async, apply_conf, &reloading);
       } else {
         engine_logger(log_info_message, most) << "Already reloading...";
-        log_v2::process()->info("Already reloading...");
+        process_logger->info("Already reloading...");
       }
       _need_reload = 0;
     }
@@ -182,35 +179,35 @@ void loop::_dispatching() {
 
     // Log messages about event lists.
     engine_logger(dbg_events, more) << "** Event Check Loop";
-    log_v2::events()->debug("** Event Check Loop");
+    events_logger->debug("** Event Check Loop");
     if (!_event_list_high.empty()) {
       engine_logger(dbg_events, more)
           << "Next High Priority Event Time: "
           << my_ctime(&(*_event_list_high.begin())->run_time);
-      log_v2::events()->debug("Next High Priority Event Time: {}",
-                              my_ctime(&(*_event_list_high.begin())->run_time));
+      events_logger->debug("Next High Priority Event Time: {}",
+                           my_ctime(&(*_event_list_high.begin())->run_time));
     } else {
       engine_logger(dbg_events, more)
           << "No high priority events are scheduled...";
-      log_v2::events()->debug("No high priority events are scheduled...");
+      events_logger->debug("No high priority events are scheduled...");
     }
     if (!_event_list_low.empty()) {
       engine_logger(dbg_events, more)
           << "Next Low Priority Event Time:  "
           << my_ctime(&(*_event_list_low.begin())->run_time);
-      log_v2::events()->debug("Next Low Priority Event Time:  {}",
-                              my_ctime(&(*_event_list_low.begin())->run_time));
+      events_logger->debug("Next Low Priority Event Time:  {}",
+                           my_ctime(&(*_event_list_low.begin())->run_time));
     } else {
       engine_logger(dbg_events, more)
           << "No low priority events are scheduled...";
-      log_v2::events()->debug("No low priority events are scheduled...");
+      events_logger->debug("No low priority events are scheduled...");
     }
     engine_logger(dbg_events, more)
         << "Current/Max Service Checks: " << currently_running_service_checks
         << '/' << config->max_parallel_service_checks();
-    log_v2::events()->debug("Current/Max Service Checks: {}/{}",
-                            currently_running_service_checks,
-                            config->max_parallel_service_checks());
+    events_logger->debug("Current/Max Service Checks: {}/{}",
+                         currently_running_service_checks,
+                         config->max_parallel_service_checks());
 
     // Update status information occassionally - NagVis watches the
     // NDOUtils DB to see if Engine is alive.
@@ -264,7 +261,7 @@ void loop::_dispatching() {
               << ") has been reached!  Nudging " << temp_service->get_hostname()
               << ":" << temp_service->description() << " by " << nudge_seconds
               << " seconds...";
-          log_v2::events()->trace(
+          events_logger->trace(
               "**WARNING** Max concurrent service checks ({}/{}) has been "
               "reached!  Nudging {}:{} by {} seconds...",
               currently_running_service_checks,
@@ -279,7 +276,7 @@ void loop::_dispatching() {
               << ") has been reached.  Nudging " << temp_service->get_hostname()
               << ":" << temp_service->description() << " by " << nudge_seconds
               << " seconds...";
-          log_v2::runtime()->warn(
+          runtime_logger->warn(
               "\tMax concurrent service checks ({}/{}) has been reached.  "
               "Nudging {}:{} by {} seconds...",
               currently_running_service_checks,
@@ -294,7 +291,7 @@ void loop::_dispatching() {
           engine_logger(dbg_events | dbg_checks, more)
               << "We're not executing service checks right now, "
               << "so we'll skip this event.";
-          log_v2::events()->debug(
+          events_logger->debug(
               "We're not executing service checks right now, so we'll skip "
               "this event.");
           run_event = false;
@@ -330,12 +327,11 @@ void loop::_dispatching() {
             else
               temp_service->set_next_check(
                   (time_t)(temp_service->get_next_check() +
-                           (temp_service->check_interval() *
-                            config->interval_length())));
+                           (temp_service->check_interval() * interval_length)));
           }
           temp_event->run_time = temp_service->get_next_check();
           reschedule_event(std::move(temp_event), events::loop::low);
-          temp_service->update_status();
+          temp_service->update_status(notifier::status_attribute::NEXT_CHECK);
           run_event = false;
         }
       }
@@ -352,7 +348,7 @@ void loop::_dispatching() {
           engine_logger(dbg_events | dbg_checks, more)
               << "We're not executing host checks right now, "
               << "so we'll skip this event.";
-          log_v2::events()->debug(
+          events_logger->debug(
               "We're not executing host checks right now, so we'll skip this "
               "event.");
           run_event = false;
@@ -383,7 +379,7 @@ void loop::_dispatching() {
                                                    config->interval_length()));
           temp_event->run_time = temp_host->get_next_check();
           reschedule_event(std::move(temp_event), events::loop::low);
-          temp_host->update_status();
+          temp_host->update_status(notifier::status_attribute::NEXT_CHECK);
           run_event = false;
         }
       }
@@ -397,7 +393,7 @@ void loop::_dispatching() {
 
         // Handle the event.
         engine_logger(dbg_events, more) << "Running event...";
-        log_v2::events()->debug("Running event...");
+        events_logger->debug("Running event...");
         temp_event->handle_timed_event();
 
         // Reschedule the event if necessary.
@@ -408,7 +404,7 @@ void loop::_dispatching() {
       else {
         engine_logger(dbg_events, most)
             << "Did not execute scheduled event. Idling for a bit...";
-        log_v2::events()->debug(
+        events_logger->debug(
             "Did not execute scheduled event. Idling for a bit...");
         uint64_t d = static_cast<uint64_t>(config->sleep_time() * 1000000000);
         std::this_thread::sleep_for(std::chrono::nanoseconds(d));
@@ -421,7 +417,7 @@ void loop::_dispatching() {
               current_time < (*_event_list_low.begin())->run_time)) {
       engine_logger(dbg_events, most)
           << "No events to execute at the moment. Idling for a bit...";
-      log_v2::events()->debug(
+      events_logger->debug(
           "No events to execute at the moment. Idling for a bit...");
 
       // Check for external commands if we're supposed to check as
@@ -463,170 +459,6 @@ void loop::_dispatching() {
   }
 }
 
-/**
- *  Adjusts scheduling of host and service checks.
- */
-void loop::adjust_check_scheduling() {
-  static double const projected_host_check_overhead(0.1);
-  static double const projected_service_check_overhead(0.1);
-  double current_exec_time(0.0);
-  double current_exec_time_offset(0.0);
-  double exec_time_factor(0.0);
-  double inter_check_delay(0.0);
-  double last_check_exec_time(0.0);
-  double total_check_exec_time(0.0);
-  int adjust_scheduling(false);
-  int total_checks(0);
-  time_t last_check_time(0L);
-  host* hst(nullptr);
-  com::centreon::engine::service* svc(nullptr);
-
-  engine_logger(dbg_functions, basic) << "adjust_check_scheduling()";
-  log_v2::functions()->trace("adjust_check_scheduling()");
-
-  /* TODO:
-     - Track host check overhead on a per-host basis
-     - Figure out how to calculate service check overhead
-  */
-
-  // determine our adjustment window.
-  time_t current_time(time(nullptr));
-  time_t first_window_time(current_time);
-  time_t last_window_time(first_window_time +
-                          config->auto_rescheduling_window());
-
-  // get current scheduling data.
-  for (timed_event_list::iterator it{_event_list_low.begin()},
-       end{_event_list_low.end()};
-       it != end; ++it) {
-    // skip events outside of our current window.
-    if ((*it)->run_time <= first_window_time)
-      continue;
-    if ((*it)->run_time > last_window_time)
-      break;
-
-    if ((*it)->event_type == timed_event::EVENT_HOST_CHECK) {
-      if (!(hst = (host*)(*it)->event_data))
-        continue;
-
-      // ignore forced checks.
-      if (hst->get_check_options() & CHECK_OPTION_FORCE_EXECUTION)
-        continue;
-
-      // does the last check "bump" into this one?
-      if ((last_check_time + last_check_exec_time) > (*it)->run_time)
-        adjust_scheduling = true;
-
-      last_check_time = (*it)->run_time;
-
-      // calculate time needed to perform check.
-      // NOTE: host check execution time is not taken into account,
-      // as scheduled host checks are run in parallel.
-      last_check_exec_time = projected_host_check_overhead;
-      total_check_exec_time += last_check_exec_time;
-    } else if ((*it)->event_type == timed_event::EVENT_SERVICE_CHECK) {
-      if (!(svc = (com::centreon::engine::service*)(*it)->event_data))
-        continue;
-
-      // ignore forced checks.
-      if (svc->get_check_options() & CHECK_OPTION_FORCE_EXECUTION)
-        continue;
-
-      // does the last check "bump" into this one?
-      if ((last_check_time + last_check_exec_time) > (*it)->run_time)
-        adjust_scheduling = true;
-
-      last_check_time = (*it)->run_time;
-
-      // calculate time needed to perform check.
-      // NOTE: service check execution time is not taken into
-      // account, as service checks are run in parallel.
-      last_check_exec_time = projected_service_check_overhead;
-      total_check_exec_time += last_check_exec_time;
-    } else
-      continue;
-
-    ++total_checks;
-  }
-
-  // nothing to do...
-  if (total_checks == 0 || adjust_scheduling == false)
-    return;
-
-  if ((unsigned long)total_check_exec_time >
-      config->auto_rescheduling_window()) {
-    inter_check_delay = 0.0;
-    exec_time_factor = (double)((double)config->auto_rescheduling_window() /
-                                total_check_exec_time);
-  } else {
-    inter_check_delay = (double)((((double)config->auto_rescheduling_window()) -
-                                  total_check_exec_time) /
-                                 (double)(total_checks * 1.0));
-    exec_time_factor = 1.0;
-  }
-
-  auto compute_new_run_time = [](double current_exec_time_offset,
-                                 double current_icd_offset,
-                                 time_t first_window_time) {
-    double offset = current_exec_time_offset + current_icd_offset;
-    time_t retval = first_window_time + static_cast<unsigned long>(offset);
-    return retval;
-  };
-  // adjust check scheduling.
-  double current_icd_offset(inter_check_delay / 2.0);
-  for (timed_event_list::iterator it = _event_list_low.begin(),
-                                  end = _event_list_low.end();
-       it != end; ++it) {
-    // skip events outside of our current window.
-    if ((*it)->run_time <= first_window_time)
-      continue;
-    if ((*it)->run_time > last_window_time)
-      break;
-
-    if ((*it)->event_type == timed_event::EVENT_HOST_CHECK) {
-      if (!(hst = (host*)(*it)->event_data))
-        continue;
-
-      // ignore forced checks.
-      if (hst->get_check_options() & CHECK_OPTION_FORCE_EXECUTION)
-        continue;
-
-      current_exec_time =
-          (hst->get_execution_time() + projected_host_check_overhead) *
-          exec_time_factor;
-      time_t new_run_time = compute_new_run_time(
-          current_exec_time_offset, current_icd_offset, first_window_time);
-      (*it)->run_time = new_run_time;
-      hst->set_next_check(new_run_time);
-      hst->update_status();
-    } else if ((*it)->event_type == timed_event::EVENT_SERVICE_CHECK) {
-      if (!(svc = (com::centreon::engine::service*)(*it)->event_data))
-        continue;
-
-      // ignore forced checks.
-      if (svc->get_check_options() & CHECK_OPTION_FORCE_EXECUTION)
-        continue;
-
-      // NOTE: service check execution time is not taken into
-      // account, as service checks are run in parallel.
-      current_exec_time = projected_service_check_overhead * exec_time_factor;
-      time_t new_run_time = compute_new_run_time(
-          current_exec_time_offset, current_icd_offset, first_window_time);
-      (*it)->run_time = new_run_time;
-      svc->set_next_check(new_run_time);
-      svc->update_status();
-    } else
-      continue;
-
-    current_icd_offset += inter_check_delay;
-    current_exec_time_offset += current_exec_time;
-  }
-
-  // resort event list (some events may be out of order at
-  // this point).
-  resort_event_list(events::loop::low);
-}
-
 /**
  *  Attempts to compensate for a change in the system time.
  *
@@ -642,7 +474,7 @@ void loop::compensate_for_system_time_change(unsigned long last_time,
   long time_difference = current_time - last_time;
 
   engine_logger(dbg_functions, basic) << "compensate_for_system_time_change()";
-  log_v2::functions()->trace("compensate_for_system_time_change()");
+  functions_logger->trace("compensate_for_system_time_change()");
 
   // we moved back in time...
   if (time_difference < 0) {
@@ -650,9 +482,8 @@ void loop::compensate_for_system_time_change(unsigned long last_time,
     engine_logger(dbg_events, basic)
         << "Detected a backwards time change of " << days << "d " << hours
         << "h " << minutes << "m " << seconds << "s.";
-    log_v2::events()->trace(
-        "Detected a backwards time change of {}d {}h {}m {}s.", days, hours,
-        minutes, seconds);
+    events_logger->trace("Detected a backwards time change of {}d {}h {}m {}s.",
+                         days, hours, minutes, seconds);
   }
   // we moved into the future...
   else {
@@ -660,9 +491,8 @@ void loop::compensate_for_system_time_change(unsigned long last_time,
     engine_logger(dbg_events, basic)
         << "Detected a forwards time change of " << days << "d " << hours
         << "h " << minutes << "m " << seconds << "s.";
-    log_v2::events()->trace(
-        "Detected a forwards time change of {}d {}h {}m {}s.", days, hours,
-        minutes, seconds);
+    events_logger->trace("Detected a forwards time change of {}d {}h {}m {}s.",
+                         days, hours, minutes, seconds);
   }
 
   // log the time change.
@@ -671,7 +501,7 @@ void loop::compensate_for_system_time_change(unsigned long last_time,
       << minutes << "m " << seconds << "s ("
       << (time_difference < 0 ? "backwards" : "forwards")
       << " in time) has been detected.  Compensating...";
-  log_v2::runtime()->warn(
+  runtime_logger->warn(
       "Warning: A system time change of {}d {}h {}m {}s ({} in time) has been "
       "detected.  Compensating...",
       days, hours, minutes, seconds,
@@ -809,7 +639,7 @@ void loop::compensate_for_system_time_change(unsigned long last_time,
 void loop::add_event(std::unique_ptr<timed_event>&& event,
                      loop::priority priority) {
   engine_logger(dbg_functions, basic) << "add_event()";
-  log_v2::functions()->trace("add_event()");
+  functions_logger->trace("add_event()");
 
   timed_event_list* list;
 
@@ -845,7 +675,7 @@ void loop::add_event(std::unique_ptr<timed_event>&& event,
 
 void loop::remove_downtime(uint64_t downtime_id) {
   engine_logger(dbg_functions, basic) << "loop::remove_downtime()";
-  log_v2::functions()->trace("loop::remove_downtime()");
+  functions_logger->trace("loop::remove_downtime()");
 
   for (auto it = _event_list_high.begin(), end = _event_list_high.end();
        it != end; ++it) {
@@ -870,7 +700,7 @@ void loop::remove_downtime(uint64_t downtime_id) {
 void loop::remove_event(timed_event_list::iterator& it,
                         loop::priority priority) {
   engine_logger(dbg_functions, basic) << "loop::remove_event()";
-  log_v2::functions()->trace("loop::remove_event()");
+  functions_logger->trace("loop::remove_event()");
 
   if (priority == loop::low)
     _event_list_low.erase(it);
@@ -886,7 +716,7 @@ void loop::remove_event(timed_event_list::iterator& it,
  */
 void loop::remove_event(timed_event* evt, loop::priority priority) {
   engine_logger(dbg_functions, basic) << "loop::remove_event()";
-  log_v2::functions()->trace("loop::remove_event()");
+  functions_logger->trace("loop::remove_event()");
   timed_event_list* list;
   if (priority == loop::low)
     list = &_event_list_low;
@@ -923,7 +753,7 @@ timed_event_list::iterator loop::find_event(loop::priority priority,
   timed_event_list* list;
 
   engine_logger(dbg_functions, basic) << "resort_event_list()";
-  log_v2::functions()->trace("resort_event_list()");
+  functions_logger->trace("resort_event_list()");
 
   // move current event list to temp list.
   if (priority == loop::low)
@@ -948,7 +778,7 @@ timed_event_list::iterator loop::find_event(loop::priority priority,
 void loop::reschedule_event(std::unique_ptr<timed_event>&& event,
                             loop::priority priority) {
   engine_logger(dbg_functions, basic) << "reschedule_event()";
-  log_v2::functions()->trace("reschedule_event()");
+  functions_logger->trace("reschedule_event()");
 
   // reschedule recurring events...
   if (event->recurring) {
@@ -987,7 +817,7 @@ void loop::resort_event_list(loop::priority priority) {
   timed_event_list* list;
 
   engine_logger(dbg_functions, basic) << "resort_event_list()";
-  log_v2::functions()->trace("resort_event_list()");
+  functions_logger->trace("resort_event_list()");
 
   // move current event list to temp list.
   if (priority == loop::low)
