@@ -1,23 +1,23 @@
-/*
-** Copyright 1999-2009      Ethan Galstad
-** Copyright 2009-2012      Icinga Development Team (http://www.icinga.org)
-** Copyright 2011-2014,2016 Centreon
-**
-** This file is part of Centreon Engine.
-**
-** Centreon Engine is free software: you can redistribute it and/or
-** modify it under the terms of the GNU General Public License version 2
-** as published by the Free Software Foundation.
-**
-** Centreon Engine is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-** General Public License for more details.
-**
-** You should have received a copy of the GNU General Public License
-** along with Centreon Engine. If not, see
-** <http://www.gnu.org/licenses/>.
-*/
+/**
+ * Copyright 1999-2009      Ethan Galstad
+ * Copyright 2009-2012      Icinga Development Team (http://www.icinga.org)
+ * Copyright 2011-2014,2016 Centreon
+ *
+ * This file is part of Centreon Engine.
+ *
+ * Centreon Engine is free software: you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License version 2
+ * as published by the Free Software Foundation.
+ *
+ * Centreon Engine is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with Centreon Engine. If not, see
+ * <http://www.gnu.org/licenses/>.
+ */
 
 #include "com/centreon/engine/utils.hh"
 
@@ -32,13 +32,13 @@
 #include "com/centreon/engine/broker.hh"
 #include "com/centreon/engine/broker/loader.hh"
 #include "com/centreon/engine/checks/checker.hh"
-#include "com/centreon/engine/commands/raw.hh"
+#include "com/centreon/engine/commands/connector.hh"
+#include "com/centreon/engine/commands/raw_v2.hh"
 #include "com/centreon/engine/comment.hh"
 #include "com/centreon/engine/configuration/applier/state.hh"
 #include "com/centreon/engine/downtimes/downtime_manager.hh"
 #include "com/centreon/engine/events/loop.hh"
 #include "com/centreon/engine/globals.hh"
-#include "com/centreon/engine/log_v2.hh"
 #include "com/centreon/engine/logging/logger.hh"
 #include "com/centreon/engine/macros.hh"
 #include "com/centreon/engine/nebmods.hh"
@@ -58,12 +58,12 @@ using namespace com::centreon::engine::logging;
 int my_system_r(nagios_macros* mac,
                 std::string const& cmd,
                 int timeout,
-                int* early_timeout,
+                bool* early_timeout,
                 double* exectime,
                 std::string& output,
                 unsigned int max_output_length) {
   engine_logger(dbg_functions, basic) << "my_system_r()";
-  log_v2::functions()->trace("my_system_r()");
+  functions_logger->trace("my_system_r()");
 
   // initialize return variables.
   *early_timeout = false;
@@ -75,7 +75,7 @@ int my_system_r(nagios_macros* mac,
   }
 
   engine_logger(dbg_commands, more) << "Running command '" << cmd << "'...";
-  SPDLOG_LOGGER_DEBUG(log_v2::commands(), "Running command '{}'...", cmd);
+  SPDLOG_LOGGER_DEBUG(commands_logger, "Running command '{}'...", cmd);
 
   timeval start_time = timeval();
   timeval end_time = timeval();
@@ -83,20 +83,15 @@ int my_system_r(nagios_macros* mac,
   // time to start command.
   gettimeofday(&start_time, nullptr);
 
-  // send event broker.
-  broker_system_command(NEBTYPE_SYSTEM_COMMAND_START, NEBFLAG_NONE,
-                        NEBATTR_NONE, start_time, end_time, *exectime, timeout,
-                        *early_timeout, service::state_ok,
-                        const_cast<char*>(cmd.c_str()), nullptr, nullptr);
-
-  commands::raw raw_cmd("system", cmd);
+  std::shared_ptr<commands::raw_v2> raw_cmd =
+      std::make_shared<commands::raw_v2>(g_io_context, "system", cmd);
   commands::result res;
-  raw_cmd.run(cmd, *mac, timeout, res);
+  raw_cmd->run(cmd, *mac, timeout, res);
 
   end_time.tv_sec = res.end_time.to_seconds();
   end_time.tv_usec = res.end_time.to_useconds() - end_time.tv_sec * 1000000ull;
   *exectime = (res.end_time - res.start_time).to_seconds();
-  *early_timeout = res.exit_status == process::timeout;
+  *early_timeout = res.exit_status == common::e_exit_status::timeout;
   if (max_output_length > 0)
     output = res.output.substr(0, max_output_length - 1);
   else
@@ -109,16 +104,10 @@ int my_system_r(nagios_macros* mac,
       << " sec, early timeout=" << *early_timeout << ", result=" << result
       << ", output=" << output;
   SPDLOG_LOGGER_DEBUG(
-      log_v2::commands(),
+      commands_logger,
       "Execution time={:.3f} sec, early timeout={}, result={}, output={}",
       *exectime, *early_timeout, result, output);
 
-  // send event broker.
-  broker_system_command(NEBTYPE_SYSTEM_COMMAND_END, NEBFLAG_NONE, NEBATTR_NONE,
-                        start_time, end_time, *exectime, timeout,
-                        *early_timeout, result, const_cast<char*>(cmd.c_str()),
-                        const_cast<char*>(output.c_str()), nullptr);
-
   return result;
 }
 
@@ -144,7 +133,7 @@ int get_raw_command_line_r(nagios_macros* mac,
   int escaped = false;
 
   engine_logger(dbg_functions, basic) << "get_raw_command_line_r()";
-  log_v2::functions()->trace("get_raw_command_line_r()");
+  functions_logger->trace("get_raw_command_line_r()");
 
   /* clear the argv macros */
   clear_argv_macros_r(mac);
@@ -156,7 +145,7 @@ int get_raw_command_line_r(nagios_macros* mac,
 
   engine_logger(dbg_commands | dbg_checks | dbg_macros, most)
       << "Raw Command Input: " << cmd_ptr->get_command_line();
-  SPDLOG_LOGGER_DEBUG(log_v2::commands(), "Raw Command Input: {}",
+  SPDLOG_LOGGER_DEBUG(commands_logger, "Raw Command Input: {}",
                       cmd_ptr->get_command_line());
 
   /* get the full command line */
@@ -209,7 +198,7 @@ int get_raw_command_line_r(nagios_macros* mac,
 
   engine_logger(dbg_commands | dbg_checks | dbg_macros, most)
       << "Expanded Command Output: " << full_command;
-  SPDLOG_LOGGER_DEBUG(log_v2::commands(), "Expanded Command Output: {}",
+  SPDLOG_LOGGER_DEBUG(commands_logger, "Expanded Command Output: {}",
                       full_command);
 
   return OK;
@@ -420,6 +409,15 @@ void cleanup() {
   // Unload modules.
   if (!test_scheduling && !verify_config) {
     checks::checker::deinit();
+    /* Before stopping, we stop all the connectors that are not already
+     * finished. */
+    for (auto& c : commands::connector::connectors)
+      c.second->stop_connector();
+
+    /* Before stopping, we destroy all the running checks that are not already
+     * finished. */
+    com::centreon::engine::commands::command::commands.clear();
+
     neb_free_callback_list();
     neb_unload_all_modules(NEBMODULE_FORCE_UNLOAD, sigshutdown
                                                        ? NEBMODULE_NEB_SHUTDOWN
