@@ -1,4 +1,4 @@
-/*
+/**
  * Copyright 2017 - 2019 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -38,7 +38,7 @@
 #include "com/centreon/engine/configuration/state.hh"
 #include "com/centreon/engine/downtimes/downtime_manager.hh"
 #include "com/centreon/engine/exceptions/error.hh"
-#include "com/centreon/engine/log_v2.hh"
+#include "com/centreon/engine/globals.hh"
 #include "com/centreon/engine/retention/dump.hh"
 #include "com/centreon/engine/timezone_manager.hh"
 
@@ -54,7 +54,7 @@ class HostNotification : public TestEngine {
   void SetUp() override {
     init_config_state();
 
-    log_v2::events()->set_level(spdlog::level::off);
+    events_logger->set_level(spdlog::level::off);
 
     configuration::applier::contact ct_aply;
     configuration::contact ctct{new_configuration_contact("admin", true)};
