@@ -1,4 +1,4 @@
-/*
+/**
  * Copyright 2019 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -17,9 +17,6 @@
  *
  */
 
-#include <cstring>
-#include <regex>
-
 #include "../test_engine.hh"
 #include "../timeperiod/utils.hh"
 #include "com/centreon/engine/checks/checker.hh"
@@ -64,6 +61,8 @@ class ServiceFlappingNotification : public TestEngine {
     hst.parse("address", "127.0.0.1");
     hst.parse("_HOST_ID", "12");
     hst.parse("check_command", "cmd");
+    hst.parse("active_checks_enabled", "0");
+    hst.parse("passive_checks_enabled", "1");
     hst_aply.add_object(hst);
     hst_aply.resolve_object(hst);
 
@@ -96,6 +95,7 @@ class ServiceFlappingNotification : public TestEngine {
     _host->set_state_type(checkable::hard);
     _host->set_acknowledgement(AckType::NONE);
     _host->set_notify_on(static_cast<uint32_t>(-1));
+    _host->set_check_type(checkable::check_type::check_passive);
   }
 
   void TearDown() override {
@@ -441,9 +441,15 @@ TEST_F(ServiceFlappingNotification, CheckFlappingWithVolatile) {
   ASSERT_EQ(m9, std::string::npos);
 }
 
+/**
+ * @brief Given a host down, we generate a flapping service and notifications
+ * should not be called
+ *
+ */
 TEST_F(ServiceFlappingNotification, CheckFlappingWithHostDown) {
   _host->set_current_state(engine::host::state_down);
   _host->set_state_type(checkable::hard);
+  _host->set_check_type(checkable::check_type::check_passive);
   config->enable_flap_detection(true);
   _service->set_flap_detection_enabled(true);
   _service->add_flap_detection_on(engine::service::ok);
