@@ -42,7 +42,9 @@ if [ "$1" = "configure" ] ; then
     /var/lib/centreon-engine \
     /var/log/centreon-engine
   chmod -R g+w \
-    /etc/centreon-engine \
+    /etc/centreon-engine
+
+  chmod -R 0755 \
     /var/log/centreon-engine
 fi
 
